# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgname openvswitch3.2


%if 0%{?commit:1}
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%endif

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# FIXME Test "STP - flush the fdb and mdb when topology changed" fails on s390x
# FIXME 2 tests fails on ppc64le. They will be hopefully fixed before official 2.11
%ifarch %{ix86} x86_64 aarch64
%bcond_without check
%else
%bcond_with check
%endif
# option to run kernel datapath tests, requires building as root!
%bcond_with check_datapath_kernel
# option to build with libcap-ng, needed for running OVS as regular user
%bcond_without libcapng
# option to build with ipsec support
%bcond_without ipsec

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

Name: %{pkgname}
Summary: Open vSwitch
Group: System Environment/Daemons daemon/database/utilities
URL: http://www.openvswitch.org/
Version: 3.2.0
Release: 130%{?dist}

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
# datapath/ is GPLv2 (although not built into any of the binary packages)
License: ASL 2.0 and LGPLv2+ and SISSL

%define dpdkver 22.11.1
%define dpdkdir dpdk
%define dpdksver %(echo %{dpdkver} | cut -d. -f-2)
# NOTE: DPDK does not currently build for s390x
# DPDK on aarch64 is not stable enough to be enabled in FDP
%if 0%{?rhel} > 7 || 0%{?fedora}
%define dpdkarches x86_64 ppc64le
%else
%define dpdkarches
%endif

%if 0%{?commit:1}
Source: https://github.com/openvswitch/ovs/archive/%{commit}.tar.gz#/openvswitch-%{commit}.tar.gz
%else
Source: https://github.com/openvswitch/ovs/archive/v%{version}.tar.gz#/openvswitch-%{version}.tar.gz
%endif
Source2: openvswitch.sysusers
Source3: openvswitch-hugetlbfs.sysusers
Source10: https://fast.dpdk.org/rel/dpdk-%{dpdkver}.tar.xz

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.2.3
%define pyelftoolsver 0.27
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz
Source103: https://pypi.io/packages/source/p/pyelftools/pyelftools-%{pyelftoolsver}.tar.gz

%define apply_patch %(test -s %{_sourcedir}/openvswitch-%{version}.patch && echo 1 || echo 0)

%if %{apply_patch}
Patch0:    openvswitch-%{version}.patch
%endif

# The DPDK is designed to optimize througput of network traffic using, among
# other techniques, carefully crafted assembly instructions.  As such it
# needs extensive work to port it to other architectures.
ExclusiveArch: x86_64 aarch64 ppc64le s390x

# Do not enable this otherwise YUM will break on any upgrade.
# Provides: openvswitch
Conflicts: openvswitch < 3.2
Conflicts: openvswitch-dpdk < 3.2
Conflicts: openvswitch2.10
Conflicts: openvswitch2.11
Conflicts: openvswitch2.12
Conflicts: openvswitch2.13
Conflicts: openvswitch2.14
Conflicts: openvswitch2.15
Conflicts: openvswitch2.16
Conflicts: openvswitch2.17
Conflicts: openvswitch3.0
Conflicts: openvswitch3.1

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units systemd-rpm-macros openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel
BuildRequires: systemtap-sdt-devel
# make check dependencies
BuildRequires: procps-ng
%if %{with check_datapath_kernel}
BuildRequires: nmap-ncat
# would be useful but not available in RHEL or EPEL
#BuildRequires: pyftpdlib
%endif

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

%ifarch %{dpdkarches}
BuildRequires: meson
%if 0%{?rhel} > 8 || 0%{?fedora}
BuildRequires: python3-pyelftools
%endif
# DPDK driver dependencies
BuildRequires: zlib-devel numactl-devel libarchive-devel
%ifarch x86_64
BuildRequires: rdma-core-devel >= 15 libmnl-devel
%endif

# Required by packaging policy for the bundled DPDK
Provides: bundled(dpdk) = %{dpdkver}
%endif

Requires: openssl iproute module-init-tools
#Upstream kernel commit 4f647e0a3c37b8d5086214128614a136064110c3
#Requires: kernel >= 3.15.0-0
Requires: openvswitch-selinux-extra-policy

%{?sysusers_requires_compat}
Requires(post): /bin/sed
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Obsoletes: openvswitch-controller <= 0:2.1.0-1

%if 0%{?rhel}
# sortedcontainers are not packaged on RHEL yet, but ovs includes it
%global __requires_exclude ^python%{python3_version}dist\\(sortedcontainers\\)$
%endif

%description
Open vSwitch provides standard network bridging functions and
support for the OpenFlow protocol for remote per-flow control of
traffic.

%package -n python3-%{pkgname}
Summary: Open vSwitch python3 bindings
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Provides: python-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description -n python3-%{pkgname}
Python bindings for the Open vSwitch database

%package test
Summary: Open vSwitch testing utilities
License: ASL 2.0
BuildArch: noarch
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: tcpdump

%description test
Utilities that are useful to diagnose performance and connectivity
issues in Open vSwitch setup.

%package devel
Summary: Open vSwitch OpenFlow development package (library, headers)
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description devel
This provides shared library, libopenswitch.so and the openvswitch header
files needed to build an external application.

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%package -n network-scripts-%{name}
Summary: Open vSwitch legacy network service support
License: ASL 2.0
Requires: network-scripts
Supplements: (%{name} and network-scripts)

%description -n network-scripts-%{name}
This provides the ifup and ifdown scripts for use with the legacy network
service.
%endif

%if %{with ipsec}
%package ipsec
Summary: Open vSwitch IPsec tunneling support
License: ASL 2.0
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: libreswan

%description ipsec
This package provides IPsec tunneling support for OVS tunnels.
%endif

%prep
%if 0%{?commit:1}
%setup -q -n ovs-%{commit} -a 10
%else
%setup -q -n ovs-%{version} -a 10
%endif
%if ! %{external_sphinx}
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 100 -a 101 -a 102
%else
%setup -n ovs-%{version} -q -D -T -a 100 -a 101 -a 102
%endif
%endif
%if 0%{?rhel} && 0%{?rhel} < 9
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 103
%else
%setup -n ovs-%{version} -q -D -T -a 103
%endif
%endif

mv dpdk-*/ %{dpdkdir}/

%if %{apply_patch}
%patch0 -p1
%endif

%build
%if 0%{?rhel} && 0%{?rhel} < 9
export PYTHONPATH="${PWD}/pyelftools-%{pyelftoolsver}"
%endif
# Build Sphinx on RHEL
%if ! %{external_sphinx}
export PYTHONPATH="${PYTHONPATH:+$PYTHONPATH:}%{_builddir}/pytmp/lib/python"
for x in docutils-%{docutilsver} Pygments-%{pygmentsver} Sphinx-%{sphinxver}; do
    pushd "$x"
    python2 setup.py install --home %{_builddir}/pytmp
    popd
done

export PATH="$PATH:%{_builddir}/pytmp/bin"
%endif

./boot.sh

%ifarch %{dpdkarches}    # build dpdk
# Lets build DPDK first
cd %{dpdkdir}

ENABLED_DRIVERS=(
    bus/pci
    bus/vdev
    mempool/ring
    net/failsafe
    net/i40e
    net/ring
    net/vhost
    net/virtio
    net/tap
)

%ifarch x86_64
ENABLED_DRIVERS+=(
    bus/auxiliary
    bus/vmbus
    common/iavf
    common/mlx5
    net/bnxt
    net/enic
    net/iavf
    net/ice
    net/mlx5
    net/netvsc
    net/nfp
    net/qede
    net/vdev_netvsc
)
%endif

%ifarch aarch64 x86_64
ENABLED_DRIVERS+=(
    net/e1000
    net/ixgbe
)
%endif

for driver in "${ENABLED_DRIVERS[@]}"; do
    enable_drivers="${enable_drivers:+$enable_drivers,}"$driver
done

# As of 21.11-rc3, following libraries can be disabled:
# optional_libs = [
#         'bitratestats',
#         'gpudev',
#         'gro',
#         'gso',
#         'kni',
#         'jobstats',
#         'latencystats',
#         'metrics',
#         'pdump',
#         'power',
#         'vhost',
# ]
# If doing any updates, this must be aligned with:
# https://access.redhat.com/articles/3538141
DISABLED_LIBS=(
    gpudev
    kni
    jobstats
    power
)

for lib in "${DISABLED_LIBS[@]}"; do
    disable_libs="${disable_libs:+$disable_libs,}"$lib
done

%set_build_flags
%__meson --prefix=%{_builddir}/dpdk-build \
         --buildtype=plain \
         -Ddisable_libs="$disable_libs" \
         -Ddisable_apps="*" \
         -Denable_drivers="$enable_drivers" \
         -Dplatform=generic \
         -Dmax_ethports=1024 \
         -Dmax_numa_nodes=8 \
         -Dtests=false \
         %{_vpath_builddir}
%meson_build
%__meson install -C %{_vpath_builddir} --no-rebuild

# FIXME currently with LTO enabled OVS tries to link with both static and shared libraries
rm -v %{_builddir}/dpdk-build/%{_lib}/*.so*

# Generate a list of supported drivers, its hard to tell otherwise.
cat << EOF > README.DPDK-PMDS
DPDK drivers included in this package:

EOF

for f in %{_builddir}/dpdk-build/%{_lib}/librte_net_*.a; do
    basename ${f} | cut -c12- | cut -d. -f1 | tr [:lower:] [:upper:]
done >> README.DPDK-PMDS

cat << EOF >> README.DPDK-PMDS

For further information about the drivers, see
http://dpdk.org/doc/guides-%{dpdksver}/nics/index.html
EOF

cd -
%endif    # build dpdk

# And now for OVS...
mkdir build-shared build-static
pushd build-shared
ln -s ../configure
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --disable-static \
        --enable-shared \
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes \
        --disable-afxdp \
        --with-version-suffix=-%{release}
make %{?_smp_mflags}
popd
pushd build-static
ln -s ../configure
%ifarch %{dpdkarches}
PKG_CONFIG_PATH=%{_builddir}/dpdk-build/%{_lib}/pkgconfig \
%endif
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
%ifarch %{dpdkarches}
        --with-dpdk=static \
%endif
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes \
        --disable-afxdp \
        --with-version-suffix=-%{release}
make %{?_smp_mflags}
popd

/usr/bin/python3 build-aux/dpdkstrip.py \
        --dpdk \
        < rhel/usr_lib_systemd_system_ovs-vswitchd.service.in \
        > rhel/usr_lib_systemd_system_ovs-vswitchd.service

%install
rm -rf $RPM_BUILD_ROOT
make -C build-shared install sbin_PROGRAMS=ovsdb/ovsdb-server DESTDIR=$RPM_BUILD_ROOT
make -C build-static install bin_PROGRAMS= sbin_PROGRAMS=vswitchd/ovs-vswitchd DESTDIR=$RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_rundir}/openvswitch
install -d -m 0750 $RPM_BUILD_ROOT%{_localstatedir}/log/openvswitch
install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch

install -p -D -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysusersdir}/openvswitch.conf
%ifarch %{dpdkarches}
install -p -D -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysusersdir}/openvswitch-hugetlbfs.conf
%endif

install -p -D -m 0644 rhel/usr_lib_udev_rules.d_91-vfio.rules \
        $RPM_BUILD_ROOT%{_udevrulesdir}/91-vfio.rules

install -p -D -m 0644 \
        rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/openvswitch

for service in openvswitch ovsdb-server ovs-vswitchd \
               ovs-delete-transient-ports; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

%if %{with ipsec}
install -p -D -m 0644 rhel/usr_lib_systemd_system_openvswitch-ipsec.service \
                      $RPM_BUILD_ROOT%{_unitdir}/openvswitch-ipsec.service
%endif

install -m 0755 rhel/etc_init.d_openvswitch \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/openvswitch.init

install -p -D -m 0644 rhel/etc_openvswitch_default.conf \
        $RPM_BUILD_ROOT/%{_sysconfdir}/openvswitch/default.conf

install -p -D -m 0644 rhel/etc_logrotate.d_openvswitch \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/openvswitch

install -m 0644 vswitchd/vswitch.ovsschema \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/vswitch.ovsschema

%if 0%{?rhel} < 9
install -d -m 0755 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{python3_sitelib}
cp -a $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/ovstest \
        $RPM_BUILD_ROOT%{python3_sitelib}

# Build the JSON C extension for the Python lib (#1417738)
pushd python
(
export CPPFLAGS="-I ../include -I ../build-shared/include"
export LDFLAGS="%{__global_ldflags} -L $RPM_BUILD_ROOT%{_libdir}"
%py3_build
%py3_install
[ -f "$RPM_BUILD_ROOT/%{python3_sitearch}/ovs/_json$(python3-config --extension-suffix)" ]
)
popd

rm -rf $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/openvswitch

install -d -m 0755 $RPM_BUILD_ROOT%{_prefix}/lib/firewalld/services/

install -p -D -m 0755 \
        rhel/usr_share_openvswitch_scripts_ovs-systemd-reload \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovs-systemd-reload

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db
# The db needs special permission as IPsec Pre-shared keys are stored in it.
chmod 0640 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/system-id.conf

# remove unpackaged files
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovs-benchmark \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-docker \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-parse-backtrace \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-testcontroller \
        $RPM_BUILD_ROOT/%{_sbindir}/ovs-vlan-bug-workaround \
        $RPM_BUILD_ROOT/%{_mandir}/man1/ovs-benchmark.1* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-testcontroller.* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-vlan-bug-workaround.8*

%if ! %{with ipsec}
rm -f $RPM_BUILD_ROOT/%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%endif

# remove ovn unpackages files
rm -f $RPM_BUILD_ROOT%{_bindir}/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovn*
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*

%check
%if %{with check}
    pushd build-static
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if make check TESTSUITEFLAGS='%{_smp_mflags}' ||
       make check TESTSUITEFLAGS='--recheck'; then :;
    else
        cat tests/testsuite.log
        exit 1
    fi
    popd
%endif
%if %{with check_datapath_kernel}
    pushd build-static
    if make check-kernel RECHECK=yes; then :;
    else
        cat tests/system-kmod-testsuite.log
        exit 1
    fi
    popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?systemd_preun:1}
    %systemd_preun openvswitch.service
%else
    if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
        /bin/systemctl --no-reload disable openvswitch.service >/dev/null 2>&1 || :
        /bin/systemctl stop openvswitch.service >/dev/null 2>&1 || :
    fi
%endif

%pre
%sysusers_create_compat %{SOURCE2}
%ifarch %{dpdkarches}
%sysusers_create_compat %{SOURCE3}
%endif

%post
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVS_USER_ID=:OVS_USER_ID=:' /etc/sysconfig/openvswitch

%ifarch %{dpdkarches}
    sed -i \
        's@OVS_USER_ID="openvswitch:openvswitch"@OVS_USER_ID="openvswitch:hugetlbfs"@'\
        /etc/sysconfig/openvswitch
%endif
fi
chown -R openvswitch:openvswitch /etc/openvswitch

%if 0%{?systemd_post:1}
    %systemd_post openvswitch.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun
%if 0%{?systemd_postun:1}
    %systemd_postun openvswitch.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif

%triggerun -- openvswitch < 2.5.0-22.git20160727%{?dist}
# old rpm versions restart the service in postun, but
# due to systemd some preparation is needed.
if systemctl is-active openvswitch >/dev/null 2>&1 ; then
    /usr/share/openvswitch/scripts/ovs-ctl stop >/dev/null 2>&1 || :
    systemctl daemon-reload >/dev/null 2>&1 || :
    systemctl stop openvswitch ovsdb-server ovs-vswitchd >/dev/null 2>&1 || :
    systemctl start openvswitch >/dev/null 2>&1 || :
fi
exit 0

%files -n python3-%{pkgname}
%{python3_sitearch}/ovs
%{python3_sitearch}/ovs-*.egg-info
%doc LICENSE

%files test
%{_bindir}/ovs-pcap
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_datadir}/openvswitch/scripts/usdt/*
%{_mandir}/man1/ovs-pcap.1*
%{_mandir}/man8/ovs-tcpdump.8*
%{_mandir}/man1/ovs-tcpundump.1*
%{_bindir}/ovs-test
%{_bindir}/ovs-vlan-test
%{_bindir}/ovs-l3ping
%{_mandir}/man8/ovs-test.8*
%{_mandir}/man8/ovs-vlan-test.8*
%{_mandir}/man8/ovs-l3ping.8*
%{python3_sitelib}/ovstest

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openvswitch/*
%{_includedir}/openflow/*
%exclude %{_libdir}/*.a
%exclude %{_libdir}/*.la

%if 0%{?rhel} == 8 || 0%{?fedora} > 28
%files -n network-scripts-%{name}
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%files
%defattr(-,openvswitch,openvswitch)
%dir %{_sysconfdir}/openvswitch
%{_sysconfdir}/openvswitch/default.conf
%config %ghost %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/conf.db
%ghost %attr(0600,-,-) %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/.conf.db.~lock~
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%defattr(-,root,root)
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/openvswitch
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovsdb-server.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovs-delete-transient-ports.service
%{_datadir}/openvswitch/scripts/openvswitch.init
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-kmod-ctl
%{_datadir}/openvswitch/scripts/ovs-systemd-reload
%config %{_datadir}/openvswitch/local-config.ovsschema
%config %{_datadir}/openvswitch/vswitch.ovsschema
%config %{_datadir}/openvswitch/vtep.ovsschema
%{_bindir}/ovs-appctl
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_bindir}/ovs-pki
%{_bindir}/vtep-ctl
%{_libdir}/*.so.*
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%{_mandir}/man1/ovsdb-client.1*
%{_mandir}/man1/ovsdb-server.1*
%{_mandir}/man1/ovsdb-tool.1*
%{_mandir}/man5/ovsdb.5*
%{_mandir}/man5/ovsdb.local-config.5*
%{_mandir}/man5/ovsdb-server.5.*
%{_mandir}/man5/ovs-vswitchd.conf.db.5*
%{_mandir}/man5/vtep.5*
%{_mandir}/man7/ovsdb-server.7*
%{_mandir}/man7/ovsdb.7*
%{_mandir}/man7/ovs-actions.7*
%{_mandir}/man7/ovs-fields.7*
%{_mandir}/man8/vtep-ctl.8*
%{_mandir}/man8/ovs-appctl.8*
%{_mandir}/man8/ovs-ctl.8*
%{_mandir}/man8/ovs-dpctl.8*
%{_mandir}/man8/ovs-kmod-ctl.8.*
%{_mandir}/man8/ovs-ofctl.8*
%{_mandir}/man8/ovs-pki.8*
%{_mandir}/man8/ovs-vsctl.8*
%{_mandir}/man8/ovs-vswitchd.8*
%{_mandir}/man8/ovs-parse-backtrace.8*
%{_udevrulesdir}/91-vfio.rules
%doc LICENSE NOTICE README.rst NEWS rhel/README.RHEL.rst
%ifarch %{dpdkarches}
%doc %{dpdkdir}/README.DPDK-PMDS
%attr(750,openvswitch,hugetlbfs) %verify(not owner group) /var/log/openvswitch
%else
%attr(750,openvswitch,openvswitch) %verify(not owner group) /var/log/openvswitch
%endif
/var/lib/openvswitch
%ghost %attr(755,root,root) %verify(not owner group) %{_rundir}/openvswitch
%{_datadir}/openvswitch/bugtool-plugins/
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_bindir}/ovs-dpctl-top
%{_sbindir}/ovs-bugtool
%{_mandir}/man8/ovs-dpctl-top.8*
%{_mandir}/man8/ovs-bugtool.8*
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} < 29)
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif
%{_sysusersdir}/openvswitch.conf
%ifarch %{dpdkarches}
%{_sysusersdir}/openvswitch-hugetlbfs.conf
%endif

%if %{with ipsec}
%files ipsec
%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%{_unitdir}/openvswitch-ipsec.service
%endif

%changelog
* Tue May 13 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-130
- Merging upstream branch-3.2 [RH git: 2f2ef79166]
    Commit list:
    f31735f70f github: Add a permanent workaround for malformed /etc/hosts.


* Wed Apr 30 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-129
- Merging upstream branch-3.2 [RH git: a71d75c0bc]
    Commit list:
    b4ed49d28c python: idl: Clear rows without losing indexes.


* Mon Apr 28 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-128
- Merging upstream branch-3.2 [RH git: 94579bdbfc]
    Commit list:
    474f765f32 ipsec: libreswan: Fix detection of loaded IPv6 connections. (FDP-1328)


* Fri Apr 25 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-127
- Merging upstream branch-3.2 [RH git: 35aa97f1eb]
    Commit list:
    aa89d450e0 uuid: Fix a warning about zero byte truncation in the template.
    07bb9bbf7d dpdk: Fix main lcore on systems with many cores. (FDP-1312)
    443f7b233a ovs-vtep: Fix vlan binding.
    f6b56de721 ipf: Maintain packet zone and direction. (FDP-1052)
    541f12cb23 ipf: Don't send expired frags. (FDP-1052)


* Thu Apr 03 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-126
- Merging upstream branch-3.2 [RH git: a070e23540]
    Commit list:
    1f3232b757 python: Disable check for globals with never reassigned names (F824).
    2fb823abeb ofproto-dpif: Fix spelling in comments and the support field macro.
    a78108e9c1 rhel/systemd: Change owner recursively and also on /etc/openvswitch.


* Wed Mar 26 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-125
- Merging upstream branch-3.2 [RH git: ca815b4cc3]
    Commit list:
    316b0ffd74 tests: ovsdb-idl: Fix flaky insert and delete tests.
    9310e17a34 python: stream: Fix unlink attempt for ptcp IP address.


* Fri Mar 21 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-124
- Merging upstream branch-3.2 [RH git: 66d8f1cd85]
    Commit list:
    6c9c906fa0 ofproto-dpif: Fix dp_hash mapping after select group modification. ()


* Tue Mar 18 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-123
- Merging upstream branch-3.2 [RH git: cc5cc13012]
    Commit list:
    b53b7455d2 tests: Disable rate limiting for tests parsing flow dumps from logs. ()


* Fri Mar 07 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-122
- Merging upstream branch-3.2 [RH git: ea1b1f0586]
    Commit list:
    dca13c9c85 github: Get sparse from the official GitHub mirror.


* Fri Feb 28 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-121
- Merging upstream branch-3.2 [RH git: e48554605f]
    Commit list:
    c35ff51722 python: ovsdb-idl: Fix persist_uuid references.
    3db925a972 python: ovsdb-idl: Handle inserts w/o changes.


* Thu Feb 27 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-120
- Merging upstream branch-3.2 [RH git: 3e91737540]
    Commit list:
    226eab26b0 Prepare for 3.2.6.
    d9485c5982 Set release date for 3.2.5.


* Wed Feb 26 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-119
- Merging upstream branch-3.2 [RH git: dde2299284]
    Commit list:
    04c8708db6 ofproto-dpif-xlate: Fix source IP lookup for non-bridge ports.


* Thu Feb 20 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-118
- Merging upstream branch-3.2 [RH git: 39933c35d6]
    Commit list:
    487c1bb9be miniflow_extract: Push ct_tp_{src, dst} for later frags. (FDP-124)


* Tue Feb 18 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-117
- Merging dpdk subtree [RH git: fe4bcd9f65]
    Commit list:
    29498facc5 Merge tag 'v22.11.7' into 22.11
    7ce7d3341d version: 22.11.7
    1570aef08b net/virtio: fix Rx checksum calculation
    92bac8b798 Revert "test/bonding: fix loop on members"
    d752210315 power: fix log message when checking lcore ID
    077a7044cc net/hns3: fix crash for NEON and SVE
    09fb920298 version: 22.11.7-rc1
    07d2440237 devtools: fix check of multiple commits fixed at once
    fec1fb4800 doc: correct definition of stats per queue feature
    8d8d069395 app/testpmd: remove redundant policy action condition
    0cbed5e68f test/eal: fix lcore check
    f7b5b45e72 test/eal: fix loop coverage for alignment macros
    c6448283e3 test/event: avoid duplicate initialization
    d82f1f8760 test/bonding: fix MAC address comparison
    634cf74378 test/bonding: fix loop on members
    65491527fa net/mlx5: fix miniCQEs number calculation
    2e0f9b4eab app/testpmd: fix aged flow destroy
    ad0890d82f member: fix choice of bucket for displacement
    0b010067c3 app/procinfo: fix leak on exit
    50b8a025c8 common/dpaax/caamflib: enable fallthrough warnings
    e4545205cc net/i40e: check register read for outer VLAN
    cc6ceb096e net/iavf: add segment-length check to Tx prep
    cc3d964ab6 bus/dpaa: fix lock condition during error handling
    d3789f7b2e net/mlx5: fix Rx queue reference count in flushing flows
    318bb3c11d net/mlx5: fix default RSS flows creation order
    102f2042b2 common/mlx5: fix misalignment
    0e162f1a25 net/mlx5: fix counter query loop getting stuck
    08bdeeee6b net/mlx5/hws: fix allocation of STCs
    da5d3d9ce9 net/mlx5: fix shared queue port number in vector Rx
    aabf15baa5 common/mlx5: fix error CQE handling for 128 bytes CQE
    591f0841c6 net/dpaa2: remove unnecessary check for null before free
    af71652ab7 eventdev: fix possible array underflow/overflow
    a137ec4342 examples/l2fwd-event: fix spinlock handling
    0bb02c5a2f net/cnxk: fix build on Ubuntu 24.04
    fcd2d7fa43 common/cnxk: fix build on Ubuntu 24.04
    e768697485 net/bnx2x: fix duplicate branch
    0ff8ac46ba net/bnx2x: fix possible infinite loop at startup
    3b501926d5 net/bnx2x: fix always true expression
    17006eb028 net/bnx2x: remove dead conditional
    a73ed9bb24 net/bnxt: fix bad action offset in Tx BD
    3d5d7a20e0 net/bnxt: fix TCP and UDP checksum flags
    881d93b709 net/bnxt: fix reading SFF-8436 SFP EEPROMs
    768828f6a2 net/bnxt/tf_ulp: fix parent child DB counters
    0c320c9667 net/bnxt/tf_core: fix Thor TF EM key size check
    aa75cb3e6e net/mlx5: fix real time counter reading from PCI BAR
    802f39367e crypto/qat: fix modexp/inv length
    9c9057bd06 test/crypto: fix synchronous API calls
    1811b05443 crypto/openssl: fix potential string overflow
    6e9955ee17 baseband/acc: fix ring memory allocation
    75ff38855b event/octeontx: fix possible integer overflow
    78043bb867 net/hns3: fix fully use hardware flow director table
    e3cf757040 net/hns3: fix error code for repeatedly create counter
    dd372d9141 net/vmxnet3: support larger MTU with version 6
    d19359e017 net/vmxnet3: fix potential out of bounds stats access
    ded9039ea9 net/ngbe: restrict configuration of VLAN strip offload
    8d3229e87a net/ngbe: fix interrupt lost in legacy or MSI mode
    c9d9948b04 net/ngbe: reconfigure more MAC Rx registers
    fb66eb3c8a net/ngbe: fix driver load bit to inform firmware
    205cc63ef8 net/txgbe: fix driver load bit to inform firmware
    ecf3bccd94 net/txgbe: remove outer UDP checksum capability
    dfc18e3532 net/txgbe: fix VF-PF mbox interrupt
    f6b5dc92b0 net/txgbe: fix SWFW mbox
    88a272ed2c net/hns3: remove ROH devices
    9af4afb790 net/vmxnet3: fix crash after configuration failure
    b704e087ff net/netvsc: force Tx VLAN offload on 801.2Q packet
    b4cf08fc16 examples/ntb: check info query return
    9ce0bf0e89 test/bonding: remove redundant info query
    c0989bd756 examples/l3fwd: fix read beyond boundaries
    60135d1bde net/dpaa2: fix memory corruption in TM
    96ae1b7103 bus/fslmc: fix Coverity warnings in QBMAN
    95b15d5ff8 app/dumpcap: remove unused struct array
    77ffd1395b net/mlx5: fix reported Rx/Tx descriptor limits
    34e44ab00c net/mlx5: fix SWS meter state initialization
    12f2bc90eb net/mlx5: fix SQ flow item size
    505c7f3f0a net/mlx5: fix GRE flow item translation for root table
    614c294ea5 net/mlx5: fix memory leak in metering
    298a19d6d8 eal/unix: optimize thread creation
    15f924f62f crypto/openssl: fix 3DES-CTR with big endian CPUs
    7c2c50cb67 config/arm: fix warning for native build with meson >= 0.55
    b6454df58c net/mvneta: fix possible out-of-bounds write
    a4ee1170ef net/ixgbe: fix link status delay on FreeBSD
    3dac25dc58 net/ice: detect stopping a flow director queue twice
    b207e53f27 net/hns3: restrict tunnel flow rule to one header
    44c959d8c3 net/netvsc: fix using Tx queue higher than Rx queues
    8a4a31ed6e buildtools/chkincs: check driver specific headers
    3ca6090a4f net/mlx5: fix flex item header length field translation
    3db5656f1d net/mlx5: fix non full word sample fields in flex item
    c837dececb net/mlx5: update flex parser arc types support
    0fc5b4da10 pcapng: fix handling of chained mbufs
    eaf081b5aa common/idpf: fix use after free in mailbox init
    04984dc016 net/idpf: fix AVX-512 pointer copy on 32-bit
    8c1ee8e80c net/ionic: fix build on Fedora Rawhide
    a73f3a97ff power: fix mapped lcore ID
    1e230f1ca2 net/gve/base: fix build with Fedora Rawhide
    45655bbf59 dmadev: fix potential null pointer access
    fec66c08d4 hash: fix thash LFSR initialization
    70c3227ccd build: remove version check on compiler links function
    9015591db9 net/mlx5: fix next protocol validation after flex item
    a56fc269ef app/testpmd: remove flex item init command leftover
    f12c8f789d net/mlx5: fix number of supported flex parsers
    09fbaf6867 net/mlx5: workaround list management of Rx queue control
    873da637bb net/iavf: preserve MAC address with i40e PF Linux driver
    47a2900e1c net/ice/base: fix VLAN replay after reset
    19bb1781fe net/ice/base: add bounds check
    2012542358 net/pcap: fix blocking Rx
    4e6b6c42ce net/nfp: fix link change return value
    1cdad91ab4 net/hns3: verify reset type from firmware
    856f4dd1d2 ethdev: verify queue ID in Tx done cleanup
    1ef2a5f5f6 net/tap: restrict maximum number of MP FDs
    270f15f3fd net/memif: fix buffer overflow in zero copy Rx
    30d634d95f net/dpaa: fix reallocate mbuf handling
    9bc6a69f0b bus/dpaa: fix the fman details status
    6770a35bbf bus/dpaa: fix VSP for 1G fm1-mac9 and 10
    b4daf0e0fd net/dpaa: fix typecasting channel ID
    0c1fd86cee bus/dpaa: fix PFDRs leaks due to FQRNIs
    a905d9d63e ethdev: fix overflow in descriptor count
    9c49c19a4d net/hns3: fix dump counter of registers
    849ffb29c6 net/hns3: remove some basic address dump
    e7c27b6ffe net/ena: revert redefining memcpy
    ead6f2f7f7 net/mana: support rdma-core via pkg-config
    d3a78f0f8f net/pcap: set live interface as non-blocking
    7b317b7db9 app/testpmd: remove unnecessary cast
    8b8b03abd8 net/tap: avoid memcpy with null argument
    b25fb707fa net/iavf: fix AVX-512 pointer copy on 32-bit
    8c93fc7726 net/ice: fix AVX-512 pointer copy on 32-bit
    0d727f9dd2 net/i40e: fix AVX-512 pointer copy on 32-bit
    6c69f14358 net/i40e/base: fix loop bounds
    75db5f0032 net/i40e/base: fix unchecked return value
    92dd240303 net/i40e/base: fix repeated register dumps
    e06d6a124e net/i40e/base: fix DDP loading with reserved track ID
    a6d819d27a net/i40e/base: fix blinking X722 with X557 PHY
    aea7ea7acb net/i40e/base: fix misleading debug logs and comments
    b2571f3563 net/i40e/base: fix setting flags in init function
    c2cd652d0f net/ixgbe/base: fix unchecked return value
    822d0a9391 net/ice/base: fix iteration of TLVs in Preserved Fields Area
    6970864b0c net/ice/base: fix link speed for 200G
    90adb751e4 net/iavf: fix crash when link is unstable
    5780ca90f0 net/e1000: fix link status crash in secondary process
    c0c610f426 fib: fix AVX512 lookup
    768ca32567 net/virtio-user: reset used index counter
    8473106d0c vdpa: update used flags in used ring relay
    659d8ff0cf vhost: fix offset while mapping log base address
    e8d41d4db2 baseband/acc: fix access to deallocated mem
    5c7ce1ed01 common/cnxk: fix base log level
    0b67f7f759 common/cnxk: fix CPT HW word size for outbound SA
    082cd77172 event/cnxk: fix Rx timestamp handling
    1601beceba net/cnxk: fix Rx offloads to handle timestamp
    8d056353d1 net/cnxk: fix Rx timestamp handling for VF
    65c229defe app/dumpcap: fix handling of jumbo frames
    e696cfc2f8 fib6: add runtime checks in AVX512 lookup
    2bb52b6763 power: enable CPPC
    d56b8cfa79 net/nfb: fix use after free
    afdb0a605d examples/vhost: fix free function mismatch
    8a86016238 raw/ifpga: fix free function mismatch in interrupt config
    f838b3c8b9 raw/ifpga/base: fix use after free
    d8c04bbc9b net/sfc: fix use after free in debug logs
    8bd09aed9c net/nfp: fix double free in flow destroy
    7a1ad4c97e net/e1000: fix use after free in filter flush
    4cf7c66de7 event/cnxk: fix free function mismatch in port config
    495fd2e8ca dma/idxd: fix free function mismatch in device probe
    08043b1ad9 crypto/bcmfs: fix free function mismatch
    38eba244a3 baseband/la12xx: fix use after free in modem config
    b6364f5406 bpf: fix free function mismatch if convert fails
    4152dbbb8e examples/ipsec-secgw: fix dequeue count from cryptodev
    66228c9ae7 dev: fix callback lookup when unregistering device
    0900241918 common/dpaax/caamflib: fix PDCP SNOW-ZUC watchdog
    3ae58cc9a3 crypto/dpaa2_sec: fix memory leak
    44c20cfd7a examples/eventdev: fix queue crash with generic pipeline
    fdda4a8d41 eal/x86: fix 32-bit write combining store
    8a32360685 devtools: fix forbidden token check with multiple files


* Fri Feb 14 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-116
- Merging upstream branch-3.2 [RH git: e003b61ddc]
    Commit list:
    898ef685ca dpif-netdev: Fix Auto Load Balance debug log. (FDP-1145)


* Fri Jan 24 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-115
- Merging upstream branch-3.2 [RH git: 9ba79ad138]
    Commit list:
    becd379a03 dpdk: Use DPDK 22.11.7 release for OVS 3.2.


* Wed Jan 15 2025 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-114
- Merging upstream branch-3.2 [RH git: 203e49ad08]
    Commit list:
    d6e3fe6227 dpif-netdev: Modify code comments for function parse_tcp_flags.
    2a52bb6fa7 ipf: Fix the over-sized reassembly.


* Fri Dec 13 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-113
- Merging upstream branch-3.2 [RH git: cc730aaaef]
    Commit list:
    5871f321a8 m4: Fix check for Python 3.6 version.


* Wed Dec 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-112
- Merging upstream branch-3.2 [RH git: 658df78e7f]
    Commit list:
    ebcbf71dca cirrus: Update to FreeBSD 14.2 and 13.4.
    81ee17e4dd bridge: Fix log spam about prefixes.


* Fri Nov 29 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-111
- Merging upstream branch-3.2 [RH git: 4660a038ee]
    Commit list:
    80a577585b ovsdb-idl: Fix use of uninitialized datum for graph consistency check.
    4ad5da024a db-ctl-base: Fix uninitialized datum fields while checking conditions.
    c71ed61292 ovsdb-types: Fix use of uninitialized reference type.
    9a8b10f6a8 ofproto-dpif-upcall: Fix use of uninitialized missed dumps counter.
    9bf25c2626 ovs-vsctl, vtep-ctl: Silence memory sanitizer warning for longindex.
    cac84c3cb0 tests: multipath: Fix use of uninitialized wildcards.
    f2a7a5a987 stream: replay: Fix potential NULL dereference on write failure.
    18f6d09bd3 ofp-actions: Fix use of uninitialized padding in set-field.


* Sat Nov 16 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-110
- Merging upstream branch-3.2 [RH git: 33ad14ea9d]
    Commit list:
    ca497b7ee7 Prepare for 3.2.5.
    ff818a566b Set release date for 3.2.4.


* Fri Nov 15 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-109
- Merging upstream branch-3.2 [RH git: ec59c39dba]
    Commit list:
    69a3d4a437 tests: Fix transient failure in ping6 header modify. ()


* Mon Nov 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-108
- Merging upstream branch-3.2 [RH git: 4b5d54d8a5]
    Commit list:
    0249f39f3f ci: Update GitHub actions runner from Ubuntu 22.04 to 24.04.
    4957b95c90 dpdk: Fix dpdk logs being split over multiple lines.


* Sun Nov 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-107
- Merging upstream branch-3.2 [RH git: d4f7e18ff2]
    Commit list:
    7d7e001aad ipsec: libreswan: Reduce chances for crossing streams.
    12596c24d8 tests: ipsec: Check that nodes can ping each other in the NxN test.
    55bf10609b tests: ipsec: Add NxN + reconciliation test.
    c84bb635db system-tests: Verbose cleanup of ports and namespaces.
    3c26c7fad7 ipsec: Make command timeout configurable.
    0691b5b44f ipsec: libreswan: Avoid monitor hanging on stuck ipsec commands. (FDP-846)
    2406cd3c1e ipsec: libreswan: Try to bring non-active connections up.
    350013ec34 ipsec: libreswan: Reconcile missing connections periodically.
    3f6c297c17 ipsec: libreswan: Fix regexp for connections waiting on child SA.
    9cf7ba72e9 ipsec: Add a helper function to run commands from the monitor.


* Wed Oct 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-106
- Merging upstream branch-3.2 [RH git: 24c392e34e]
    Commit list:
    8e92e3f3a4 meta-flow: Fix nw_frag mask while parsing from string.
    71acf2e9ee github: Remove ASLR entropy workaround.
    6e8ffc0b2f bond: Always revalidate unbalanced bonds when active member changes. (FDP-845)
    1408151804 ofproto-dpif-upcall: Fix redundant mirror on metadata modification. (FDP-699)


* Fri Oct 25 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-105
- Merging dpdk subtree [RH git: 5a0317afa1]
    Commit list:
    7294b64b1d Revert "eal/unix: support ZSTD compression for firmware"
    3ad974b46b Merge tag 'v22.11.6' into 22.11
    d6fc7991d0 Reapply "build: add libarchive to optional external dependencies"
    ff4d4839f9 version: 22.11.6
    2480dbd434 version: 22.11.6-rc1
    29857b82e4 doc: add baseline mode in l3fwd-power guide
    b9c8076d92 doc: fix mbuf flags
    ff2d7af17a examples/ipsec-secgw: revert SA salt endianness
    b70780f316 power: increase the number of UNCORE frequencies
    e224810340 doc: remove reference to mbuf pkt field
    28c93c22f7 examples: fix port ID restriction
    6a1313b34a examples: fix lcore ID restriction
    3b8becb93e examples: fix queue ID restriction
    15ac04a068 net/ice/base: fix temporary failures reading NVM
    4568f7b753 net/hns3: fix uninitialized variable in FEC query
    b9b793c805 examples/l3fwd: fix crash on multiple sockets
    68b33da50f examples/l3fwd: fix crash in ACL mode for mixed traffic
    3682872558 bus/vdev: fix device reinitialization
    0a15aefcc6 malloc: fix multi-process wait condition handling
    8ea890172e app/pdump: handle SIGTERM and SIGHUP
    7ecd214dda app/dumpcap: handle SIGTERM and SIGHUP
    1b1337cc93 dma/hisilicon: remove support for HIP09 platform
    635c7eaa5e bus/pci: fix FD in secondary process
    6bf6cd5184 bus/pci: fix UIO resource mapping in secondary process
    99b0e4a22c app/testpmd: fix build on signed comparison
    1092b5655f ethdev: fix device init without socket-local memory
    9c7ae1bf6d app/testpmd: add postpone option to async flow destroy
    c4f3e79ac5 ethdev: fix GENEVE option item conversion
    becd25a54a net/ark: fix index arithmetic
    1c9c96641a net/hns3: check Rx DMA address alignmnent
    5669dcea46 net/mlx5: fix disabling E-Switch default flow rules
    d69a8b5eb2 common/mlx5: remove unneeded field when modify RQ table
    751fa44c51 net/mlx5: fix uplink port probing in bonding mode
    f06e1a4e49 net/mlx5: fix end condition of reading xstats
    7aa564683c net/mlx5/hws: remove unused variable
    fdf5a81ff7 net/mlx5/hws: fix port ID on root item convert
    6da7724d9e net/mlx5/hws: fix deletion of action vport
    57ebce02cd net/mlx5: fix MTU configuration
    48bfee9777 net/mlx5: fix Arm build with GCC 9.1
    e444727915 net/ice: fix return value for raw pattern parsing
    9928f1ec31 net/ice: fix memory leaks in raw pattern parsing
    68d0c242e4 crypto/qat: fix placement of OOP offset
    327b33505c test/crypto: fix asymmetric capability test
    5456b47a3a test/crypto: remove unused stats in setup
    ffc0a0f5d9 doc: fix typo in l2fwd-crypto guide
    f4834455b2 crypto/qat: fix log message typo
    5a257288f8 test/crypto: fix allocation comment
    8e373a7f33 crypto/ipsec_mb: fix function comment
    e793a7063f crypto/qat: fix GEN4 write
    a0bb9efc61 net/nfp: fix disabling 32-bit build
    f0e36f585b net/nfp: adapt reverse sequence card
    0c73b671c8 net/nfp: remove redundant function call
    59cee7032b net/nfp: forbid offload flow rules with empty action list
    18b7942cef net/ena: fix checksum handling
    cf4bb6bffc net/ena: fix return value check
    33ddd1e51d net/ena: fix bad checksum handling
    59adabd787 net/nfp: disable ctrl VNIC queues on close
    047aff2cf1 net/ionic: fix mbuf double-free when emptying array
    087d968fc0 net/nfp: fix allocation of switch domain
    f4affbfda7 net/nfp: fix IPv6 TTL and DSCP flow action
    a91148a6fe net/vmxnet3: fix init logs
    48d15a5ef2 net/txgbe: fix Rx interrupt
    bd6f2422df net/ngbe: fix memory leaks
    c14e0d31df net/txgbe: fix memory leaks
    a51a250cc5 net/ngbe: fix MTU range
    c5accd3813 net/txgbe: fix MTU range
    0ce675d4cf net/ngbe: fix hotplug remove
    4d4117d9d9 net/txgbe: fix hotplug remove
    e8d10f45d6 net/ngbe: keep PHY power down while device probing
    8b161ee917 net/ngbe: add special config for YT8531SH-CA PHY
    ee530d3ee4 net/txgbe: fix VF promiscuous and allmulticast
    13909e4ba2 net/txgbe: reconfigure more MAC Rx registers
    7b6163ebfa net/txgbe: restrict configuration of VLAN strip offload
    a96f251def net/txgbe: fix Tx hang on queue disable
    500f540c7c net/txgbe: fix flow filters in VT mode
    f0b14e1401 net/txgbe: fix tunnel packet parsing
    40700232ba app/testpmd: fix parsing for connection tracking item
    4d92c686d6 doc: remove empty section from testpmd guide
    23e7802fa9 app/testpmd: handle IEEE1588 init failure
    4999f309fb net/ice: fix sizing of filter hash table
    d0f2f65e1f common/idpf: fix flex descriptor mask
    e804d44715 net/ice/base: fix masking when reading context
    44cb540275 net/ice/base: fix preparing PHY for timesync command
    8719d11e4b net/ice/base: fix board type definition
    ecb6c3285e net/ice/base: fix potential TLV length overflow
    39696cfa70 net/ice/base: fix check for existing switch rule
    e31db1b871 net/ice/base: fix return type of bitmap hamming weight
    92938d56d0 net/ice/base: fix GCS descriptor field offsets
    f3701c8b98 net/ice/base: fix size when allocating children arrays
    7fdbc3da5b net/ice/base: fix sign extension
    64f49919dd net/ice/base: fix memory leak in firmware version check
    7f57a7a2ce net/ice/base: fix pointer to variable outside scope
    f7dcc5e44f buildtools: fix build with clang 17 and ASan
    73a8315608 fbarray: fix finding for unaligned length
    3a0b6d25c0 net/mlx5: fix start without duplicate flow patterns
    c1257d39c7 net/dpaa: forbid MTU configuration for shared interface
    b7594f8f15 bus/dpaa: remove redundant file descriptor check
    55950c7aa5 common/dpaax: fix node array overrun
    041e6663bd common/dpaax: fix IOVA table cleanup
    75332a8da8 bus/dpaa: fix memory leak in bus scan
    b82122e2ab bus/dpaa: fix bus scan for DMA devices
    e922a98a21 app/testpmd: fix help string of BPF load command
    c74c897cfe dma/idxd: fix setup with Ubuntu 24.04
    b929a370ef eal/linux: lower log level on allocation attempt failure
    49fc31bc8b usertools/devbind: fix indentation
    58dd24b466 fbarray: fix lookbehind ignore mask handling
    2050d2ea01 fbarray: fix lookahead ignore mask handling
    8f3876f866 fbarray: fix incorrect lookbehind behavior
    e67654ca81 fbarray: fix incorrect lookahead behavior
    e8f3418f64 examples/ipsec-secgw: fix SA salt endianness
    6530bf0f6d crypto/dpaa2_sec: fix event queue user context
    ac47aa31a1 crypto/dpaa_sec: fix IPsec descriptor
    6182babbe7 common/dpaax/caamflib: fix PDCP AES-AES watchdog error
    09ca25c293 common/dpaax/caamflib: fix PDCP-SDAP watchdog error
    d0aee3876f crypto/openssl: set cipher padding once
    ccb6568398 crypto/openssl: make per-QP auth context clones
    26e1e90724 crypto/openssl: make per-QP cipher context clones
    8e32c3a94a crypto/openssl: optimize 3DES-CTR context init
    5154afdce8 crypto/openssl: fix GCM and CCM thread unsafe contexts
    7e6b9c0686 examples/fips_validation: fix dereference and out-of-bound
    3d19e7d9eb cryptodev: validate crypto callbacks from next node
    ff0ffd5338 cryptodev: fix build without crypto callbacks
    7341376515 crypto/cnxk: fix minimal input normalization
    528f8f36a8 app/crypto-perf: fix result for asymmetric
    d581598df3 app/crypto-perf: remove redundant local variable
    cbe35e02f9 baseband/la12xx: forbid secondary process
    63cc1ddb1b telemetry: fix connection parameter parsing
    e03493d52e bpf: fix load hangs with six IPv6 addresses
    d7a549306d bpf: fix MOV instruction evaluation
    f172fd7567 mbuf: fix dynamic fields copy
    2db5746bc8 vdpa/sfc: remove dead code
    e35ccc8804 dmadev: fix structure alignment
    cdb1114156 app/bbdev: fix interrupt tests
    fcfe871790 build: use builtin helper for python dependencies
    0938693288 config: fix warning for cross build with meson >= 1.3.0
    1a055be1a3 doc: fix link to hugepage mapping from Linux guide
    6a30502095 bus/vdev: revert fix devargs in secondary process
    1620b6d717 telemetry: lower log level on socket error
    5cbc25e40f test/crypto: fix enqueue/dequeue callback case
    e12b4a47ba net/mlx5: fix crash on counter pool destroy
    aadaf7fe72 net/mlx5: support jump in meter hierarchy
    739bd81a46 net/mlx5: fix access to flow template operations
    68b68c76e1 net/mlx5: break flow resource release loop
    42e1eb6a45 net/mlx5: fix flow template indirect action failure
    c8ee47f1a6 net/mlx5: fix hash Rx queue release in flow sample
    a752b66a9a net/mlx5: fix indexed pool with invalid index
    06af59ff2f net/mlx5/hws: fix action template dump
    4a75ad8a7e net/mlx5/hws: add template match none flag
    df1753ebe8 net/mlx5/hws: fix spinlock release on context open
    ef9f7c1fd8 net/mlx5/hws: fix function comment
    06de40842e common/mlx5: fix PRM structs
    a05258399a net/mlx5/hws: decrease log level for creation failure
    17c5271078 common/mlx5: fix unsigned/signed mismatch
    0ac140899b hash: fix RCU reclamation size
    1f65019c2d bpf: disable on 32-bit x86
    145220677b graph: fix ID collisions
    e0da7a253d net/cnxk: fix promiscuous state after MAC change
    d9d6771eba net/cnxk: fix outbound security with higher packet burst
    d1c48d821e net/cnxk: fix RSS config
    8873f14545 net/ixgbe/base: fix PHY ID for X550
    7b94a8b53e net/ixgbe/base: fix 5G link speed reported on VF
    5e73514050 net/ixgbe/base: revert advertising for X550 2.5G/5G
    229bdd77bb net/e1000/base: fix link power down
    b2e98edd71 net/ixgbe: do not create delayed interrupt handler twice
    23efe3ba7a net/ixgbe: do not update link status in secondary process
    f461c249ff net/fm10k: fix cleanup during init failure
    4c07a5e8c1 eal: fix logs for '--lcores'
    5575459062 eventdev/crypto: fix opaque field handling
    ae651a5adb event/sw: fix warning from useless snprintf
    d47135efe7 baseband/acc: fix memory barrier
    48fb2f00d8 net/virtio: fix MAC table update
    aff6953d46 vhost: cleanup resubmit info before inflight setup
    6267610fff vhost: fix build with GCC 13
    9cdf5aecb2 mempool: replace GCC pragma with cast
    a28f53ce9a hash: check name when creating a hash
    07f2ecf7b3 hash: fix return code description in Doxygen
    a4a27aa3e0 app/testpmd: fix lcore ID restriction
    fe02a92fcc net/iavf: remove outer UDP checksum offload for X710 VF
    9d02109d19 net/i40e: fix outer UDP checksum offload for X710
    b5fc38d53c net: fix outer UDP checksum in Intel prepare helper
    0c72bf4c1d app/testpmd: fix outer IP checksum offload
    e48c887599 net/ice: fix check for outer UDP checksum offload
    ac5a8e2ab5 net/axgbe: fix linkup in PHY status
    e8615db990 net/axgbe: delay AN timeout during KR training
    59767090cb net/axgbe: fix Tx flow on 30H HW
    08c36b23fd net/axgbe: check only minimum speed for cables
    73e8b7893e net/axgbe: fix connection for SFP+ active cables
    39527c017d net/axgbe: fix SFP codes check for DAC cables
    07b6c26ee2 net/axgbe: enable PLL control for fixed PHY modes only
    a1e4f462f3 net/axgbe: disable RRC for yellow carp devices
    b07fc265f9 net/axgbe: disable interrupts during device removal
    6aad2db82c net/axgbe: update DMA coherency values
    fac582ee7d net/axgbe: fix fluctuations for 1G Bel Fuse SFP
    ad99680c1d net/axgbe: reset link when link never comes back
    b43c908eb2 net/axgbe: fix MDIO access for non-zero ports and CL45 PHYs
    2f9077766d net/tap: fix file descriptor check in isolated flow
    19c6df9ce8 net/af_xdp: remove unused local statistic
    9e8bcd1f55 net/af_xdp: fix stats reset
    13ac242820 net/af_xdp: count mbuf allocation failures
    20c39f6a1b net/af_xdp: fix port ID in Rx mbuf
    d00a311cfb doc: fix testpmd ring size command
    a7e4b44736 net/af_packet: align Rx/Tx structs to cache line
    ac72e81041 net/hns3: disable SCTP verification tag for RSS hash input
    f8aabaa13a net/hns3: fix variable overflow
    8ec7b95de7 net/hns3: fix double free for Rx/Tx queue
    afd6de50eb net/hns3: fix Rx timestamp flag
    419ac23f30 net/hns3: fix offload flag of IEEE 1588
    6282bde96d net/bonding: fix failover time of LACP with mode 4
    541c30f3d1 net/nfp: fix representor port queue release
    0257b6327a latencystats: fix literal float suffix
    9957ef4a31 eal/windows: install sched.h file
    7cc8737e52 net/virtio-user: add memcpy check
    461739eed3 pcapng: add memcpy check
    73c189a067 eal/unix: support ZSTD compression for firmware
    502049c8b3 bus/pci: fix build with musl 1.2.4 / Alpine 3.19
    9dc3826a4a test: force IOVA mode on PPC64 without huge pages
    a409653a12 test/crypto: fix vector global buffer overflow
    15658afda0 kni: fix build with Linux 6.8
    dbd8f39c7c version: 22.11.5
    972d4c02ae net/mlx5: fix incorrect counter cache dereference
    83a31ef4d4 crypto/ipsec_mb: fix incorrectly setting cipher keys
    28d7ed224f version: 22.11.5-rc1
    bbf97a4279 net/mlx5: fix async flow create error handling
    2b8fe78bd7 net/mlx5: fix rollback on failed flow configure
    1cf5f52d1f net/mlx5: fix flow configure validation
    efe1d783f4 examples/ipsec-secgw: fix typo in error message
    8a9e1d1f86 test/cfgfile: fix typo in error messages
    f4e263b024 test/power: fix typo in error message
    eebb999b45 doc: fix typo in packet framework guide
    16eac11cb6 doc: fix typo in profiling guide
    e96de331da net/mlx5/hws: fix port ID for root table
    6409b26550 net/vmxnet3: ignore Rx queue interrupt setup on FreeBSD
    3894e82ac5 net/ena: fix mbuf double free in fast free mode
    6e39ed2088 doc: fix default IP fragments maximum in programmer guide
    6a73ac3d7a examples/ipsec-secgw: fix Rx queue ID in Rx callback
    aead7fda3f net/bnxt: fix number of Tx queues being created
    f6a26c8864 net/mlx5: fix warning about copy length
    905283004d net/mlx5: fix drop action release timing
    0ddc41f5c6 net/mlx5: fix age position in hairpin split
    3b972375de net/mlx5: prevent ioctl failure log flooding
    3be62ef2f3 net/mlx5: fix template clean up of FDB control flow rule
    7858502f9a net/mlx5: fix DR context release ordering
    fd3721be47 net/mlx5: fix IP-in-IP tunnels recognition
    03243a2773 net/mlx5: remove duplication of L3 flow item validation
    bad500334c net/mlx5: fix meter policy priority
    f5ff0aaf2e net/mlx5: fix VLAN ID in flow modify
    78b059d759 doc: update link to Windows DevX in mlx5 guide
    ec91ab121a net/mlx5: fix HWS meter actions availability
    c45c771584 net/hns3: support new device
    65b4f90e2e app/testpmd: fix error message for invalid option
    2eb0560cb0 app/testpmd: fix burst option parsing
    d6cee7ffc0 app/testpmd: fix --stats-period option check
    75b8660005 net/nfp: fix switch domain free check
    c5251ed8a6 net/ena/base: restructure interrupt handling
    ad7591896c net/ena/base: limit exponential backoff
    fd262a1e35 net/ena: fix fast mbuf free
    6d307d9eaa doc: add link speeds configuration in features table
    d50c5dfbf4 doc: add traffic manager in features table
    fc5f4ef40f net/hns3: enable PFC for all user priorities
    a56f1654c4 crypto/qat: fix crash with CCM null AAD pointer
    642fff5862 examples/ipsec-secgw: fix cryptodev to SA mapping
    a05a096f1d build: pass cflags in subproject
    244dbbf778 net/mlx5: fix flow counter cache starvation
    bd00ef3b09 examples/l3fwd: fix Rx over not ready port
    8b642184a9 examples/packet_ordering: fix Rx with reorder mode disabled
    bf8ce81fc0 test: do not count skipped tests as executed
    a985d4953e net/ice: fix version for experimental symbols
    bd47e113a2 baseband/fpga_5gnr_fec: use a better random generator
    49989423d0 net/tap: log Netlink extended ack unavailability
    7019fde3a9 test/bpf: fix mbuf init in some filter test
    af4304e8c4 test/mbuf: fix external mbuf case with assert enabled
    0426b179f3 config: fix CPU instruction set for cross-build
    ba823066bf bus/vdev: fix devargs in secondary process
    60ca8f9c76 test: fix probing in secondary process
    fccac369b5 net/mlx5: remove device status check in flow creation
    cc21b4a2d2 net/mlx5: fix counters map in bonding mode
    e7b38d0f36 net/mlx5: fix VLAN handling in meter split
    325c88d078 net/mlx5/hws: enable multiple integrity items
    ff41fc17f1 net/mlx5: fix connection tracking action validation
    c2a6e4ddca net/mlx5: fix conntrack action handle representation
    25f2e79045 net/mlx5: fix condition of LACP miss flow
    38b2735798 net/mlx5/hws: fix VLAN inner type
    afe47440d1 net/mlx5: prevent querying aged flows on uninit port
    3032a40f28 net/mlx5: fix error packets drop in regular Rx
    5126f7dd10 net/mlx5: fix use after free when releasing Tx queues
    c3d7ceece3 net/mlx5/hws: fix VLAN item in non-relaxed mode
    d458f6a235 net/mlx5/hws: check not supported fields in VXLAN
    f29c2d6b20 common/cnxk: fix possible out-of-bounds access
    a1f69f50e1 common/cnxk: remove dead code
    66dffe8a6d common/cnxk: fix link config for SDP
    ba9eb97868 net/cnxk: fix mbuf fields in multi-segment Tx
    430b2766ce common/cnxk: fix mbox struct attributes
    df9a4e91c6 net/cnxk: add cookies check for multi-segment offload
    ec9d6236d0 common/cnxk: fix RSS RETA configuration
    a2ec8fb5fa net/cnxk: fix MTU limit
    edf3fc5d23 common/cnxk: fix Tx MTU configuration
    36157ca75c net/cnxk: fix buffer size configuration
    41dcb6a83d common/cnxk: remove CN9K inline IPsec FP opcodes
    fdc5c7c46a net/bnx2x: fix warnings about memcpy lengths
    4e873a75e2 net/ice: remove incorrect 16B descriptor read block
    0d2f5b4ca1 net/iavf: remove incorrect 16B descriptor read block
    614a3bf8e0 net/i40e: remove incorrect 16B descriptor read block
    f7667994bd net/ixgbe: increase VF reset timeout
    baf1699534 net/iavf: remove error logs for VLAN offloading
    3a2d35d6e9 net/ixgbevf: fix RSS init for x550 NICs
    100e77a19e net/bnxt: fix null pointer dereference
    48309178df net/tap: fix traffic control handle calculation
    337a1fa674 net/tap: do not overwrite flow API errors
    1b8a6de75f app/testpmd: fix async flow create failure handling
    0c972805e1 app/testpmd: return if no packets in GRO heavy weight mode
    fde6a99f1c net/af_xdp: fix leak on XSK configuration failure
    d393058761 doc: fix typos in cryptodev overview
    3ebfe50507 app/crypto-perf: add missing op resubmission
    211da2b3c8 app/crypto-perf: fix out-of-place mbuf size
    2e6e29e797 app/crypto-perf: fix copy segment size
    85bd236b25 eventdev/crypto: fix enqueueing
    7a45bfba9c eventdev: fix Doxygen processing of vector struct
    ad39899ad8 eventdev: improve Doxygen comments on configure struct
    3cdb7e6d44 test/event: fix crash in Tx adapter freeing
    ede7aa11ae event/dlb2: remove superfluous memcpy
    9507b460c3 doc: fix configuration in baseband 5GNR driver guide
    fc8e14108f baseband/acc: fix common logs
    12cbf90bfa baseband/acc: fix logtypes register
    ab4db7ac79 Revert "build: add libarchive to optional external dependencies"
    782b5a22bc net/nfp: free switch domain ID on close
    51b7521551 net/nfp: fix device resource freeing
    72254c7736 net/nfp: fix device close
    b2d4e3c5da net/nfp: fix resource leak for exit of flower firmware
    eb3dcfafdb net/nfp: fix resource leak for exit of CoreNIC firmware
    bd903bd459 net/nfp: fix resource leak for flower firmware
    f12ad3f05d net/nfp: fix resource leak for CoreNIC firmware
    1997b844bf vhost: fix virtqueue access check in vhost-user setup
    aa166bc2d3 app/testpmd: fix GRO packets flush on timeout
    b14df7f20a net/mlx5: fix stats query crash in secondary process
    c7f17de89d net/mlx5: fix GENEVE option item translation
    37b1f135bf net/mlx5: remove GENEVE options length limitation
    02373cf8c2 net/mlx5/hws: fix tunnel protocol checks
    77d9b5e6d6 common/mlx5: fix duplicate read of general capabilities
    b328c4501c net/mlx5: fix GENEVE TLV option management
    5300887877 net/mlx5: fix jump action validation
    3294358b40 common/cnxk: fix VLAN check for inner header
    079911f9f2 common/cnxk: fix mbox region copy
    f1110aacd8 net/thunderx: fix DMAC control register update
    d7cb16965b net/cnxk: fix flow RSS configuration
    51f2cd1ff7 net/bnxt: fix deadlock in ULP timer callback
    d71a770231 net/bnxt: modify locking for representor Tx
    e2cfac4357 net/bnxt: fix backward firmware compatibility
    61fe746549 net/bnxt: fix speed change from 200G to 25G on Thor
    66f4540fa5 net/bnxt: fix 50G and 100G forced speed
    f94b1dffa1 net/bnxt: fix array overflow
    a254412faf net/netvsc: fix VLAN metadata parsing
    6ccc096367 net: add macros for VLAN metadata parsing
    8603dea8c5 net/memif: fix extra mbuf refcnt update in zero copy Tx
    f90918d9f4 common/sfc_efx/base: use C11 static assert
    706c98e249 net/mana: handle MR cache expansion failure
    97789491e6 net/mana: fix memory leak on MR allocation
    32bf2f21f5 net/bonding: fix flow count query
    3bd12069ce net/ionic: fix device close
    64baeefd1f net/ionic: fix RSS query
    e15d5a01b1 net/ionic: fix missing volatile type for cqe pointers
    0bef99c53e app/testpmd: fix crash in multi-process forwarding
    cf7a7b8134 drivers/net: fix buffer overflow for packet types list
    d3273299a7 net/mana: prevent values overflow returned from RDMA layer
    ef5454bbab net/vmxnet3: fix initialization on FreeBSD
    6d4646c0f7 app/testpmd: hide --bitrate-stats in help if disabled
    f3e5b61f91 doc: add --latencystats option in testpmd guide
    1822aa59af net/hns3: remove QinQ insert support for VF
    75120a950e net/hns3: fix reset level comparison
    d043fdd66e net/hns3: fix disable command with firmware
    cfeb27992c net/hns3: fix VF multiple count on one reset
    f644df1142 net/hns3: refactor handle mailbox function
    5371898fa5 net/hns3: refactor send mailbox function
    b089a189d5 net/hns3: refactor PF mailbox message struct
    0a6c163f93 net/hns3: refactor VF mailbox message struct
    173ff75d74 net/af_xdp: fix memzone leak on config failure
    bc1e0ee2a3 net/nfp: fix resource leak for PF initialization
    636a019a74 ethdev: fix NVGRE encap flow action description
    97986481e9 doc: fix commands in eventdev test tool guide
    1e4f46e6f9 test/event: skip test if no driver is present
    8dd3b5b4ab event/cnxk: fix dequeue timeout configuration
    7c0e5bd8ed app/crypto-perf: fix encrypt operation verification
    642af46b13 app/crypto-perf: fix data comparison
    ebfa161069 app/crypto-perf: fix next segment mbuf
    3d8b8805d8 common/cnxk: fix memory leak in CPT init
    c5db2d6897 examples/ipsec-secgw: fix width of variables
    fac0d1f057 cryptodev: remove unused extern variable
    86389c2bd7 vhost: fix memory leak in Virtio Tx split path
    49dfcc6ae2 vdpa/mlx5: fix queue enable drain CQ
    9b6bdd022b vhost: fix deadlock during vDPA SW live migration
    453678fc16 net/virtio: remove duplicate queue xstats
    3dab00d897 net: fix TCP/UDP checksum with padding data
    0ceab70d2c build: link static libs with whole-archive in subproject
    00a4d8525c build: fix linker warnings about undefined symbols
    0b4a4ace22 net/nfp: fix calloc parameters
    5cad6d4260 net/bnx2x: fix calloc parameters
    3dba8ba797 common/mlx5: fix calloc parameters
    477478f179 rawdev: fix calloc parameters
    ba907dffe5 dmadev: fix calloc parameters
    5b9e4068dc eventdev: fix calloc parameters
    eb18df799b pipeline: fix calloc parameters
    e0cc2baf48 examples/vhost: verify strdup return
    7d35dff74c examples/qos_sched: fix memory leak in args parsing
    25bcc3c5b7 test: verify strdup return
    c5b1021624 app/testpmd: verify strdup return
    3baa529086 app/crypto-perf: verify strdup return
    81314db4bd app/pdump: verify strdup return
    8f29f8d800 app/dumpcap: verify strdup return
    ab86b4a27a net/failsafe: fix memory leak in args parsing
    18d9de6df8 event/cnxk: verify strdup return
    705ab71cea dma/idxd: verify strdup return
    915eda4e5a bus/vdev: verify strdup return
    f0becad294 bus/fslmc: verify strdup return
    8d6011441b bus/dpaa: verify strdup return
    10d9146d6d eal: verify strdup return
    0de12cad1b event/opdl: fix compile-time check
    3c9e08f6d3 eal/x86: add AMD vendor check for TSC calibration
    8661160ad3 ci: update versions of actions in GHA
    1d8abba661 telemetry: fix empty JSON dictionaries
    5543f65075 telemetry: fix connected clients count
    d9ce83470f build: fix reasons conflict
    7d1744b05c kernel/freebsd: fix module build on FreeBSD 14
    65973f73ee net/ice: fix memory leaks
    1a93dbe667 net/ice: fix tunnel TSO capabilities
    51cb79315c net/ice: fix link update
    6bc4e06ef9 net/ixgbe: fix memoy leak after device init failure
    ae8369536d net/iavf: fix memory leak on security context error
    599593804b net/i40e: remove redundant judgment in flow parsing
    fc8cfb6a22 dma/dpaa2: fix logtype register
    cfef91b1e0 bus/ifpga: remove dead code
    d0ec6c1277 lib: remove redundant newline from logs
    31a09fab4b lib: add newline in logs
    88ba671592 lib: use dedicated logtypes and macros
    cf93b45a70 regexdev: fix logtype register
    f66284d141 hash: remove some dead code


* Tue Oct 22 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-104
- Merging upstream branch-3.2 [RH git: 993e402bf2]
    Commit list:
    b65cd33bf4 dpdk: Use DPDK 22.11.6 release for OVS 3.2.


* Mon Oct 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-103
- Merging upstream branch-3.2 [RH git: 988c5180d6]
    Commit list:
    c2f2870130 ofproto-dpif: Improve load balancing in dp_hash select groups. (FDP-826)


* Fri Sep 20 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-102
- Merging upstream branch-3.2 [RH git: 62e58d201b]
    Commit list:
    ba4b28b1ec selinux: Update policy file.


* Fri Sep 20 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-101
- Merging upstream branch-3.2 [RH git: bda1be9c38]
    Commit list:
    ec103da96b ofproto-dpif-mirror: Always revalidate on mirror update. (FDP-788)


* Mon Sep 16 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-100
- Merging upstream branch-3.2 [RH git: 1fcec6e3a9]
    Commit list:
    1e56776eff vconn: Always properly free flow stats reply.
    bc9ee566bc mcast-snooping: Properly check group_get_lru return code.
    7959967da9 ovsdb-idl: Fix IDL memory leak.
    fc2e861b97 ofproto/bond: Preserve active bond member over restarts.
    4acf9b0b71 ofproto-dpif-upcall: Avoid stale ukeys leaks.


* Tue Aug 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-99
- Merging upstream branch-3.2 [RH git: 35c31c786b]
    Commit list:
    659bbfe452 dp-packet: Correct IPv4 checksum calculation. ()


* Wed Aug 14 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-98
- Merging upstream branch-3.2 [RH git: 4d4a155af8]
    Commit list:
    3ff343a96b netdev-linux: Fix unaligned access to rpl_rtnl_link_stats64.
    cd9c2ffcb3 route-table: Fix another UBsan warning about pointer type.


* Thu Aug 08 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-97
- Merging upstream branch-3.2 [RH git: ebd0cb3338]
    Commit list:
    46cc67da40 netdev-dpdk: Fix race condition in mempool information dump.
    fb46409cdc ovsdb: transaction: Remove incorrect transaction abort in pre-commit.


* Fri Jul 26 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-96
- Use --with-version-suffix [RH git: 01fe20237b]


* Fri Jul 26 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-95
- rhel: Make the version, displayed to the user, customizable. [RH git: 580a330285]
    Since on CentOS/RHEL the builds are based on stable branches and not on
    tags for debugging purpose it's better to have the downstream version as
    version so it's easier to know which commits are included in a build.
    
    This commit adds --with-version-suffix as ./configure option in
    order to set an OVS version suffix that should be shown to the user via
    ovs-vsctl -V and, so, also on database, on ovs-vsctl show and the other
    utilities.
    
    --with-version-suffix is used in Fedora/CentOS/RHEL spec file in order to have
    the version be aligned with the downstream one.
    
    Signed-off-by: Timothy Redaelli <tredaelli@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>
    (cherry picked from commit 9e6d43ef32152527f7887d7f316a191adb5f338c)


* Fri Jul 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-94
- Merging upstream branch-3.2 [RH git: 2b764819d7]
    Commit list:
    3eca1c2c95 netlink-notifier: Silence the UBsan's function pointer mismatch error.


* Fri Jul 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-93
- Merging upstream branch-3.2 [RH git: 4bf8d038c8]
    Commit list:
    ad644eed98 Documentation: Update QEMU documentation URLs.
    acd120d524 match: Fix false-positive snprintf size warning.
    2288deb3ad util: Add non-NULL format assertion to xvasprintf.
    9c8286745c flow: Fix unaligned access to the ND target in miniflow_extract.
    6fd78d522c dpif-netlink-rtnl: Fix netdev leak in out-of-tree tunnels probe.


* Wed Jul 17 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-92
- Merging upstream branch-3.2 [RH git: 3544c84760]
    Commit list:
    8c1eca08fa dpctl: Fix netdev reference leak in "show" command.


* Wed Jul 17 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-91
- Merging upstream branch-3.2 [RH git: 331c590dbc]
    Commit list:
    d5d77951d9 tests/tunnel.at: Add geneve options mirror test.
    a4f3079eff ofproto-dpif-upcall: Fix redundant mirror on geneve tunnel options.


* Wed Jul 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-90
- Merging upstream branch-3.2 [RH git: 71031dfbe2]
    Commit list:
    9f6f9aaefe cirrus: Update to FreeBSD 14.1.


* Tue Jun 25 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-89
- Merging upstream branch-3.2 [RH git: 24fabbc203]
    Commit list:
    6133ecb225 odp-execute: Set IPv6 traffic class in AVX implementation.


* Wed Jun 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-88
- Merging upstream branch-3.2 [RH git: 4bb237d3d8]
    Commit list:
    d7707b1ec3 dpdk: Check other_config:dpdk-extra for '--lcores'.


* Fri Jun 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-87
- Merging upstream branch-3.2 [RH git: fc452dbe71]
    Commit list:
    816111af35 Prepare for 3.2.4.
    14f8765d65 Set release date for 3.2.3.


* Fri Jun 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-86
- Merging upstream branch-3.2 [RH git: 2459af6f98]
    Commit list:
    fcc1137449 python: ovs: flow: Fix nested check_pkt_len acts.
    b612222c4f python: idl: Fix index not being updated on row modification.
    8b0bbd5119 python: ovsdb-idl: Convert new_uuid insert() arg to UUID.
    585a876798 python: ovsdb-idl: Make IndexedRows mirror hmap.


* Wed Jun 05 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-85
- Merging upstream branch-3.2 [RH git: 96ddb6c5de]
    Commit list:
    75cf68eabf nsh: Add support to compose-packet and use it in system tests.
    b206321337 tests: Convert ND, MPLS and CT sendpkt tests to compose-packet.
    588bc4092a tests: sendpkt: Allow different input formats.
    371f9f725f ipf: Handle common case of ipf defragmentation.
    b7699f0bdd ipf: Only add fragments to batch of same dl_type.


* Mon Jun 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-84
- Merging upstream branch-3.2 [RH git: 2b0f80027c]
    Commit list:
    a06c735d54 tests: Fix non-portable plus match in python vlog test.


* Fri May 31 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-83
- Merging upstream branch-3.2 [RH git: 6b1ae3a4ed]
    Commit list:
    06a4f0d7e4 odp-execute: Fix AVX checksum calculation.
    1cf6e70690 ovs-ofctl: Implement compose-packet --bare [--bad-csum].


* Thu May 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-82
- Merging upstream branch-3.2 [RH git: 78ade43d4a]
    Commit list:
    f42c407ff7 dpdk: Use DPDK 22.11.5 release for OVS 3.2.


* Tue May 28 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-81
- Merging upstream branch-3.2 [RH git: 11e849f164]
    Commit list:
    6f955620fa netdev-linux: Initialize link speed in error conditions.
    1bdf7628d6 socket: Fix uninitialized values in inet_parse_ functions.
    1c793d6ce4 dpctl: Fix uninitialized value when deleting flows.
    ba14f51e3c netdev-native-tnl: Fix use of uninitialized offset on SRv6 header pop.


* Thu May 23 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-80
- Merging upstream branch-3.2 [RH git: 5da09bcf5e]
    Commit list:
    c212b9b20a atlocal: Replace deprecated pkg_resources.
    a341983a65 atlocal: Fix setting HAVE_PYTEST on unexpected errors.
    7d1b0b11da srv6: Fix misaligned writes to segment list.


* Fri May 17 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-79
- Merging upstream branch-3.2 [RH git: c37953f11f]
    Commit list:
    27841b2c18 compiler: Fix errors in Clang 17 ubsan checks.
    bad48a6eda table: Fix freeing global variable.
    a622f6cc63 vlog: Destroy async_append first then close log_fd.


* Tue May 14 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-78
- Merging upstream branch-3.2 [RH git: ff697d229b]
    Commit list:
    65960eb76b conntrack: Fully initialize conn struct before insertion.
    7f8ed26f85 conntrack: Do not use {0} to initialize unions.


* Tue May 07 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-77
- Merging upstream branch-3.2 [RH git: 875358dc66]
    Commit list:
    a3f9c5ae1b ovsdb-client: Add missing arg to help for 'dump'.


* Fri May 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-76
- Merging upstream branch-3.2 [RH git: 242679aa6d]
    Commit list:
    a38ff0a233 ofproto-dpif-trace: Fix access to an out-of-scope stack memory.
    34b4675aa6 hash, jhash: Fix unaligned access to the hash remainder.
    389a8df2fa sparse: Add additional define for sparse on GCC >= 14.


* Tue Apr 30 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-75
- Merging upstream branch-3.2 [RH git: d38df1262f]
    Commit list:
    03c165e436 sparse: Add immintrin.h header.
    f53e3568fa tc: Fix -Wgnu-variable-sized-type-not-at-end warning with Clang 18.
    d5284c2a39 tests: Fix build failure with Clang 18 due to -Wformat-truncation.


* Mon Apr 29 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-74
- Merging upstream branch-3.2 [RH git: f695da9bb6]
    Commit list:
    4e4463ca55 netdev-dpdk: Fix possible memory leak configuring VF MAC address.


* Tue Apr 23 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-73
- Merging upstream branch-3.2 [RH git: b8c1fee0b4]
    Commit list:
    f0ccdfc0b3 ovsdb: raft: Fix probe intervals after install snapshot request.
    f34dba2f50 ovsdb: raft: Fix inability to join a cluster with a large database.
    8d638257c7 rhel/systemd: Set ovsdb-server timeout to 5 minutes.


* Thu Apr 11 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-72
- Merging upstream branch-3.2 [RH git: b99645bc10]
    Commit list:
    c88a35fc29 github: Update python to 3.12.
    d41d6c16d5 ovsdb-dot: Fix flake8 issues.
    c494d7c3f0 ovsdb-doc: Fix syntax warning with Python 3.12 and flake8 issues.


* Wed Apr 10 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-71
- Merging upstream branch-3.2 [RH git: 58bf710200]
    Commit list:
    bddcf4b123 python: Remove hacking dependency and use recent flake8.
    a23eb15ab9 cirrus: Update to FreeBSD 13.3.


* Tue Apr 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-70
- Merging upstream branch-3.2 [RH git: 2dd9378db9]
    Commit list:
    fdc450427c tests: Fix compatibility issue with Python 3.13 in vlog.at.


* Fri Apr 05 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-69
- Merging upstream branch-3.2 [RH git: 32791e9658]
    Commit list:
    72ee47fd73 ofproto-dpif-upcall: Fix ukey installation failure logs and counters.


* Wed Apr 03 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-68
- Merging upstream branch-3.2 [RH git: 7d6abcedc9]
    Commit list:
    247ad83e57 conntrack: Do not use icmp reverse helper for icmpv6.
    97a3e47d7b conntrack: Fix SNAT with exhaustion system test.


* Wed Mar 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-67
- Merging upstream branch-3.2 [RH git: 5943abcb94]
    Commit list:
    780b62535f ovsdb: raft: Fix inability to join after leadership change round trip.
    406d24c199 ovsdb: raft: Fix permanent joining state on a cluster member.
    cd562af3cc ovsdb: raft: Avoid transferring leadership to unavailable servers.


* Wed Mar 27 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-66
- Merging upstream branch-3.2 [RH git: 2ef6f5cf5b]
    Commit list:
    9719f64a34 ofproto-dpif-xlate: Fix continuations with associated metering.


* Fri Mar 22 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-65
- Merging upstream branch-3.2 [RH git: 33d7b0a2ea]
    Commit list:
    03d732cc2e ovs-monitor-ipsec: LibreSwan autodetect paths. (#1975039)
    dcaae4808f route-table: Avoid routes from non-standard routing tables.


* Tue Mar 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-64
- Merging upstream branch-3.2 [RH git: 4999e2c949]
    Commit list:
    2ecb466f86 ofproto-dpif: Fix tunnel with different name del/add failure.
    f64f9a7cc9 ofpbuf: Prevent undefined behavior in ofpbuf_clone.


* Tue Mar 12 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-63
- Merging upstream branch-3.2 [RH git: 31cd5f6845]
    Commit list:
    5ef1e26cbb github: Reduce ASLR entropy to be compatible with asan in llvm 14.


* Fri Mar 08 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-62
- Merging upstream branch-3.2 [RH git: e46db9d824]
    Commit list:
    60d2254773 netdev-dpdk: Dump packets that fail Tx preparation.
    999eaf3e93 bfd: Improve state change log message. (#2258496)
    a2b0dbbf2e tests: Fix "SSL db: Implementation" test with openssl > 3.2.0.


* Fri Mar 08 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-61
- Merging upstream branch-3.2 [RH git: 84002436e5]
    Commit list:
    41a8b58aa9 conntrack: Fix flush not flushing all elements.
    ad92b0da17 conntrack: Remove nat_conn introducing key directionality.


* Fri Mar 01 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-60
- Merging upstream branch-3.2 [RH git: 03d7e8565b]
    Commit list:
    b5f2ed2a21 bond: Reset stats when deleting post recirc rule.
    3bcff01e40 ofproto-dpif-trace: Fix infinite recirculation tracing.
    3efb5ad810 ofproto-dpif-xlate: Fix ignoring IPv6 local_ip for native tunnels.
    f4a4416b38 netdev-dummy: Add local route entries for IP addresses.
    bfc212deed tests: Move the non-local port as tunnel endpoint test.
    dce943f5a8 rstp: Fix deadlock with patch ports.


* Fri Mar 01 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-59
- Merging dpdk subtree [RH git: e25c4b667f]
    Commit list:
    319a57029a Revert "build: add libarchive to optional external dependencies"
    cb88423913 Merge tag 'v22.11.4' into 22.11
    076a05a022 Reapply "net/iavf: fix abnormal disable HW interrupt"
    caf0f5d395 version: 22.11.4
    7d6f1cc05f Revert "net/iavf: fix abnormal disable HW interrupt"
    dc9c799c7d vhost: fix missing spinlock unlock
    4307659a90 net/mlx5: fix LACP redirection in Rx domain
    6ef77f2a5e net/gve: fix RX buffer size alignment
    ee2197cbd4 crypto/openssl: fix memory leaks in asym session
    02cb6cdbcd net/nfp: fix reconfigure logic of set MAC address
    9651485a36 net/nfp: fix link status interrupt
    6350131153 app/test: disable graph auto test for windows
    97cdb0db6d Revert "eventdev: fix alignment padding"
    6c688dec84 event/dlb2: fix disable PASID
    6471372564 net/hns3: fix VF reset handler interruption
    28e7716ee3 net/hns3: fix reset event status
    c5d0485861 net/hns3: fix ignored reset event
    da708a5b4e ethdev: fix ESP packet type description
    3b67c07511 mempool: clarify enqueue/dequeue ops documentation
    9c68d8a845 mempool: fix get function documentation
    9f0f54a72e doc: remove number of commands in vDPA guide
    e1aa1c2ce0 doc: fix some ordered lists
    cabe6f3bae doc: remove restriction on ixgbe vector support
    de38896353 app/pipeline: add sigint handler
    22a1b5067c test/hash: fix creation error log
    122f600818 usertools/pmdinfo: fix usage typos
    0a742f1ec0 examples/ethtool: fix pause configuration
    3ca387345f app/dumpcap: allow multiple invocations
    578b87a955 pdump: fix error number on IPC response
    364faab59a eal/windows: fix build with recent MinGW
    82dd3dde96 config: fix RISC-V native build
    2a720ab686 examples/ipsec-secgw: fix partial overflow
    b5913482ec net/mlx5: fix offset size in conntrack flow action
    434c2fc890 doc: update versions recommendations for i40e and ice
    ce75c85b4a doc: fix RSS flow description in hns3 guide
    fb6560fcfc doc: update features in hns3 guide
    6a44194cc1 doc: fix hns3 build option about max queue number
    085a72d8f8 net/txgbe: fix out of bound access
    e0fa003972 eal/riscv: fix vector type alignment
    d3741774d0 net/mlx5: fix MPRQ stride size check
    07a861e472 net/mlx5: zero UDP checksum over IPv4 in encapsulation
    c9e75ba878 net/mlx5: fix shared Rx queue list management
    4699a174ea net/mlx5: fix multi-segment Tx inline data length
    14a722ae6b net/mlx5: fix hairpin queue states
    ab46753245 net/mlx5: fix hairpin queue unbind
    480df9f41e net/mlx5: fix use after free on Rx queue start
    d32e9e689b net/mlx5: fix destroying external representor flow
    ca79cce293 net/mlx5: fix missing flow rules for external SQ
    97b9c4dca3 net/mlx5: fix counter query during port close
    49bd7912ee net/mlx5: fix validation of sample encap flow action
    f00e3b40fd net/mlx5: fix unlock mismatch
    5ff3454aac app/testpmd: fix tunnel TSO configuration
    2959baf71f app/testpmd: add explicit check for tunnel TSO
    6f1c35e7a8 app/testpmd: fix tunnel TSO capability check
    b3009db2e4 net/hns3: fix mailbox sync
    be77f806f2 test/bonding: fix uninitialized RSS configuration
    5b8da03c1d ethdev: account for smaller MTU when setting default
    5508c2d500 app/testpmd: remove useless check in TSO command
    28f7dd30ee net/sfc: remove null dereference in log
    c38b876902 meter: fix RFC4115 trTCM API Doxygen
    71876ad11a event/dlb2: fix missing queue ordering capability flag
    a998d657f5 common/cnxk: fix SDP channel mask
    0d7ea280fe net/ice: fix crash on closing representor ports
    2dfcdb87a5 test/bbdev: assert failed test for queue configure
    7b8504aee3 test/bbdev: fix Python script subprocess
    e42af2946a baseband/acc: fix TB mode on VRB1
    2e2cc882eb event/dlb2: fix name check in self-test
    2cd4ce8518 app/dumpcap: fix mbuf pool ring type
    ac8ca59223 event/dlb2: disable PASID
    5586a7be43 bus/pci: add PASID control
    dec4b39b20 build: add libarchive to optional external dependencies
    cb225e1ae9 config/arm: fix aarch32 build with GCC 13
    e787872a59 net/ice: fix Tx preparation
    8dc1b42e31 net/iavf: fix Tx preparation
    c70a8fa66e crypto/nitrox: fix panic with high number of segments
    f089d80b08 doc: update kernel module entry in QAT guide
    d7b738d6dc net/ice: fix DCF port statistics
    c7270eb8cd net/iavf: fix Tx offload flags check
    84c1679b72 net/iavf: fix indent in Tx path
    c1c417228a net/iavf: fix Tx offload mask
    ae7a0f6233 net/ice: fix L1 check interval
    f2ab72ed3d common/mlx5: fix controller index parsing
    72ab4bf42f net/mlx5: fix flow workspace double free in Windows
    f0bc006230 net/mlx5/hws: fix integrity bits level
    815a8ce067 net/mlx5: fix flow thread safety flag for HWS
    b57dd69e61 net/mlx5: fix E-Switch mirror flow rule validation
    a908d0cb5b net/mlx5: fix NIC flow capability query
    74b594dfd3 net/mlx5: fix decap action checking in sample flow
    81410056f5 net/tap: fix RSS for fragmented packets
    85b95b48ce net/nfp: fix DMA error after abnormal exit
    5b470b0567 app/procinfo: adjust format of RSS info
    df4470f94c app/procinfo: fix RSS info
    69d6a23bb1 net/tap: fix IPv4 checksum offloading
    db03b8a934 net/tap: fix L4 checksum offloading
    de2edad82b net/hns3: fix uninitialized hash algo value
    085f8342f5 net/hns3: keep set/get algo key functions local
    555126492b net/hns3: fix some error logs
    84b217ed2c net/hns3: fix some return values
    36f408b7d8 net/hns3: fix LRO offload to report
    518bc13327 net/hns3: fix setting DCB capability
    4f039a69e9 net/enic: avoid extra unlock in MTU set
    73440e9fd3 ethdev: fix 32-bit build with GCC 13
    14a4c7b3e8 net/ngbe: add proper memory barriers in Rx
    33f8a0ce2c net/txgbe: add proper memory barriers in Rx
    22b7f9edf9 net/bonding: fix possible overrun
    d3f778e077 test/bonding: add missing check
    7989293c66 test/bonding: remove unreachable statement
    8d45a7ecac net/nfp: fix reconfigure logic in VF initialization
    cb30eb9a11 net/nfp: fix reconfigure logic in PF initialization
    8dcc1b4552 net/hns3: refactor interrupt state query
    9a62d06e64 net/hns3: fix IMP or global reset
    65231cf278 net/hns3: fix multiple reset detected log
    290166c239 net/hns3: remove reset log in secondary
    c4bf1adb63 net/hns3: fix double stats for IMP and global reset
    70c868a155 net/hns3: fix unchecked Rx free threshold
    b9195e016e net/hns3: fix typo in function name
    976cefa803 app/testpmd: fix early exit from signal
    8f4eb60951 net/gve: update max Rx packet length to be based on MTU
    6f78b589c5 ethdev: fix function name in comment
    e671505da1 net/nfp: fix crash on close
    4dfec51b97 net/cnxk: fix data offset in vector Tx
    780be398dc common/cnxk: fix pool buffer size in opaque mode
    8c291d8778 vhost: fix checking virtqueue access in stats API
    a07736eb68 vhost: fix missing lock protection in power monitor API
    adae353b36 vhost: fix check on virtqueue access in in-flight getter
    7f80528fbd vhost: fix check on virtqueue access in async registration
    2dc5b2aadd vhost: fix missing check on virtqueue access
    ac1162d97a vhost: fix missing vring call check on virtqueue access
    c1001c18e6 net/virtio: fix link state interrupt vector setting
    b485fae237 net/virtio: fix missing next flag in Tx packed ring
    51205657f1 eventdev: fix missing driver names in info struct
    0beed895ef eventdev: fix device pointer for vdev-based devices
    4f5e8c612f malloc: remove return from void functions
    f2f948863b bus/ifpga: fix driver header dependency
    f42884a20c app/procinfo: remove unnecessary rte_malloc
    c20753f52f ethdev: add check in async flow action query
    b33ea9e6de net/bonding: fix link status callback stop
    d316924b1f app/testpmd: fix primary process not polling all queues
    0cece838b9 net/vmxnet3: fix Rx and Tx queue state
    bdaff48945 net/virtio: fix Rx and Tx queue state
    b1dfb750b5 net/vhost: fix Rx and Tx queue state
    dc77b5d082 net/txgbe: fix Rx and Tx queue state
    beb475c1c4 net/softnic: fix Rx and Tx queue state
    8ab4f361b0 net/sfc: fix Rx and Tx queue state
    564958b988 net/ring: fix Rx and Tx queue state
    f2edd9823d net/pfe: fix Rx and Tx queue state
    63a8198b22 net/octeontx: fix Rx and Tx queue state
    f6ec84e5e5 net/octeon_ep: fix Rx and Tx queue state
    eb53c49bad net/null: fix Rx and Tx queue state
    df52eadf8f net/ngbe: fix Rx and Tx queue state
    4e28c37ff5 net/nfp: fix Rx and Tx queue state
    e2e72d04cb net/mvpp2: fix Rx and Tx queue state
    5116feb88f net/mvneta: fix Rx and Tx queue state
    accdf4594b net/mlx4: fix Rx and Tx queue state
    26fe1d02e5 net/memif: fix Rx and Tx queue state
    1f38a20d2e net/ipn3ke: fix Rx and Tx queue state
    0d4ab569a1 net/hinic: fix Rx and Tx queue state
    2492c41642 net/enic: fix Rx and Tx queue state
    3df3bf7e5c net/enetc: fix Rx and Tx queue state
    1efb8fcf47 net/ena: fix Rx and Tx queue state
    36e418d789 net/e1000: fix Rx and Tx queue state
    ef3b3501b8 net/dpaa2: fix Rx and Tx queue state
    b97544f35a net/dpaa: fix Rx and Tx queue state
    606a11a71c net/cxgbe: fix Rx and Tx queue state
    50177d5bf1 net/bonding: fix Rx and Tx queue state
    5f75982239 net/bnxt: fix Rx and Tx queue state
    ad55189740 net/bnx2x: fix Rx and Tx queue state
    c0001c9115 net/avp: fix Rx and Tx queue state
    b4078f8a6b net/af_xdp: fix Rx and Tx queue state
    6c8f427c57 net/af_packet: fix Rx and Tx queue state
    a8fd5060ac net/mana: add missing new line to data path logs
    c6b2c85ca4 fib6: fix adding default route as first route
    e4649e8d78 fib: fix adding default route overwriting entire table
    461a81717f net/mlx5/hws: fix field copy bind
    1c9bab50cc net/mlx5: fix jump ipool entry size
    62a937220c common/mlx5: replace use of PMD log type
    8115fe3345 net/mlx5: fix leak in sysfs port name translation
    06cd13b57e net/nfp: fix initialization of physical representors
    e054f121ef net/ark: support single function with multiple port
    b796460bce net/axgbe: identify CPU with cpuid
    a7ff0ba143 net/ice: fix TSO with big segments
    a2799805b6 net/ice: remove log from Tx prepare function
    50e27677ba net/iavf: fix TSO with big segments
    235b473bf9 net/iavf: remove log from Tx prepare function
    eec9ac43a7 net/iavf: fix Tx debug
    101faaba08 net/ice: fix initial link status
    b64cc84bb5 net/iavf: fix ESN session update
    efdea6d6f4 net/iavf: unregister interrupt handler before FD close
    948b21bd59 net/iavf: fix port stats clearing
    4467e32db9 net/ice: fix TM configuration clearing
    36e302e98b net/i40e: fix buffer leak on Rx reconfiguration
    baaa298893 net/iavf: fix checksum offloading
    491e9d37c1 net/iavf: fix VLAN offload strip flag
    52c903949a net/ice: write timestamp to first segment in scattered Rx
    d4cd714640 net/i40e: fix FDIR queue receives broadcast packets
    202402218c app/bbdev: fix link with NXP LA12XX
    923d7a21ab baseband/acc: fix ACC100 HARQ input alignment
    9e7a4f889b vdpa/mlx5: fix unregister kick handler order
    529b747a92 common/cnxk: replace direct API usage in REE
    513e507ee4 common/cnxk: remove dead Meson code
    257c5a049a common/cnxk: fix RSS key configuration
    5dc2babce4 common/cnxk: fix aura disable handling
    1ef99ed9dd mempool/cnxk: fix alloc from non-EAL threads
    0da4d859cd mempool/cnxk: fix free from non-EAL threads
    2b29a7975b dma/cnxk: fix chunk buffer failure return code
    46d25f17a6 dma/cnxk: fix device reconfigure
    915fbdb681 dma/cnxk: fix device state
    ab0aa8b245 common/cnxk: fix DPI memzone name
    0259cb16f7 net/cnxk: fix uninitialized variable
    e38988edfd common/cnxk: fix incorrect aura ID
    0e8848d299 common/cnxk: fix different size bit operations
    bc87fece07 common/cnxk: fix xstats for different packet sizes
    8c360e4392 common/cnxk: fix default flow action setting
    1b7fb134d9 event/sw: fix ordering corruption with op release
    e9da79d973 eventdev/eth_rx: fix timestamp field register in mbuf
    6d49fdbd99 event/cnxk: fix context flush in port cleanup
    22d4975573 event/sw: remove obsolete comment
    bb60e98212 test/event: fix crypto null device creation
    6e9061bd77 event/cnxk: fix return values for capability API
    ba2ec17a2f eventdev/crypto: fix circular buffer full case
    15b1bc964b event/cnxk: fix CASP usage for clang
    148478f997 event/cnxk: fix getwork mode devargs parsing
    d854ba2422 eventdev: fix alignment padding
    73fa336da5 bus/pci: fix device ID log
    5a03754492 eventdev: fix symbol export for port maintenance
    f150a45b65 crypto/ipsec_mb: add dependency check for cross build
    39b817dfee crypto/cnxk: fix IPsec CCM and GCM capabilities
    40ea03b5ea crypto/qat: fix raw API null algorithm digest
    31f6839de6 test/crypto: fix typo in asym tests
    486fb2f97c test/crypto: fix return value for GMAC case
    8506f6d67c test/crypto: skip some synchronous tests with CPU crypto
    5f940557cf test/crypto: fix IV in some vectors
    e4cba3bb19 test/security: fix IPv6 next header field
    7004929e29 doc: replace code blocks with includes in security guide
    3d75e696dc crypto/dpaa_sec: fix debug prints
    00819a704d crypto/dpaa2_sec: fix debug prints
    8af3c9994e cryptodev: add missing doc for security context
    1a318a87a3 test: fix named test macro
    086e0e529e app/testpmd: fix help string
    8ef9e184ca net/gve: fix max MTU limit
    6754edbeb5 net/tap: use MAC address parse API instead of local parser
    367755a8dc net/ngbe: check process type in close operation
    a340716239 net/txgbe: check process type in close operation
    d9b0b9b3e2 net/ngbe: keep link down after device close
    adb1b60601 net/txgbe: keep link down after device close
    46e19fcf10 net/ngbe: reconfigure MAC Rx when link update
    768e6a3d83 net/txgbe: reconfigure MAC Rx when link update
    12662c8d63 net/ngbe: prevent NIC from slowing down link speed
    401b94367f net/ngbe: fix flow control
    ae0ac0ba92 net/txgbe: fix GRE tunnel packet checksum
    2c62e36805 net/txgbe: add Tx queue maximum limit
    64d7c1df88 net/netvsc: increase VSP response timeout to 60 seconds
    af391d2427 hash: align SSE lookup to scalar implementation
    421c47495c mem: fix deadlock with multiprocess
    01d3e3c456 gpu/cuda: fix build with external GDRCopy
    e55de889b7 bus/dpaa: fix build with asserts for GCC 13
    517bb40874 random: initialize state for unregistered non-EAL threads
    4e986000b1 net/hns3: fix order in NEON Rx
    0e82ee1363 net/mana: add 32-bit short doorbell
    e9ead33c9d net/mana: enable 32-bit build
    b6200f6581 app/test: fix reference to master in bonding test
    2dec2783a0 net/hns3: fix traffic management dump text alignment
    6961856e84 net/hns3: fix traffic management thread safety
    15b43a21b2 net/hns3: fix flushing multicast MAC address
    71c9f50273 net/hns3: fix error code for multicast resource
    25c73bdc49 net/hns3: fix VF default MAC modified when set failed
    ce57bf585c net/nfp: fix control message packets
    de47856936 net/sfc: add missing error code indication to MAE init path
    563e7c87df net/sfc: account for data offset on Tx
    37863f1caa net/sfc: set max Rx packet length for representors
    38b7efe568 net/bonding: fix header for C++
    f4b30c5e2a rawdev: fix device class in log message
    f76fc5ef15 eal/unix: fix firmware reading with external xz helper
    36c07ef565 mempool: fix default ops for an empty mempool
    36001100ff ci: fix race on container image name


* Fri Feb 16 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-58
- Remove .gitmodules [RH git: 110deeacdf]


* Wed Feb 14 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-57
- Merging upstream branch-3.2 [RH git: c3fd52fe9b]
    Commit list:
    a64c208146 netdev-linux: Avoid deadlock in netdev_get_speed.
    46d1f2a536 ofproto-dpif-monitor: Remove unneeded calls to clear packets.
    1e70185e9a bfd: Set proper offsets and flags in BFD packets.


* Fri Feb 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-56
- Merging upstream branch-3.2 [RH git: 45ac6932dd]
    Commit list:
    59403c48ec Prepare for 3.2.3.
    7614e02283 Set release date for 3.2.2.
    2cfbcd5247 netdev-offload-tc: Check geneve metadata length.
    7570744c5a odp: ND: Follow Open Flow spec converting from OF to DP.


* Thu Feb 08 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-55
- Merging upstream branch-3.2 [RH git: 286a4ee527]
    Commit list:
    e3bfabd257 dpdk: Use DPDK 22.11.4 release for OVS 3.2.


* Wed Jan 31 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-54
- Merging upstream branch-3.2 [RH git: fa23958c51]
    Commit list:
    61cf7110d2 github: Bump Fedora version to 39.


* Mon Jan 29 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-53
- Merging upstream branch-3.2 [RH git: d0d062524a]
    Commit list:
    49e64f13b2 github: Update versions of action dependencies (Node.js 20).


* Fri Jan 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-52
- Merging upstream branch-3.2 [RH git: a792ba9ab7]
    Commit list:
    f6757eb214 python: ovs: flow: Add meter_id to controller.
    dae1ffc17b python: ovs: flow: Make check_pkt_len action a list.
    699d26d425 python: ovs: flow: Add idle_age to openflow flows.
    5bef199078 python: tests: Refactor test_odp section testing.
    e3f2eca15d python: ovs: flow: Add dp hash and meter actions.
    1072d0d221 python: ovs: flow: Add sample to nested actions.
    065bdb3e15 python: tests: Add info and key tests for OFPFlows.
    4374b1e64e python: ovs: flow: Fix typo in n_packets.


* Fri Jan 19 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-51
- Merging upstream branch-3.2 [RH git: 081d35df71]
    Commit list:
    cd8ffc956c ovs-atomic: Fix inclusion of Clang header by GCC 14.
    b3d094b4fb ovsdb-idl.at: Test IDL behavior during database conversion.
    a1935e9628 python: idl: Handle monitor_canceled.


* Wed Jan 17 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-50
- redhat: Fix SyntaxWarnings with Python 3.12 [RH git: c0b26fd2ea]


* Mon Jan 15 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-49
- redhat: fix pkgtool for subtree [RH git: ee128f19c0]


* Mon Jan 15 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-48
- Fix README.rst to use subtree for dpdk [RH git: bdacdc3289]


* Mon Jan 15 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-47
- Use subtree for dpdk in redhat/merge [RH git: fd97fec96d]


* Mon Jan 15 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-46
- Merge commit '42ed2ce550ca14cf939c2e6cc383a54c15878b74' into private-tredaell-subtree [RH git: aa4e3a2c4c]


* Mon Jan 15 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-45
- Add 'dpdk/' from commit '9dae7a15aea76313c592c11db44e1386e85f86fe' [RH git: 6e27925dcd]
    git-subtree-dir: dpdk
    git-subtree-mainline: fd8549da9d66b42c117d8eec6af5768507501c01
    git-subtree-split: 9dae7a15aea76313c592c11db44e1386e85f86fe


* Mon Jan 15 2024 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-44
- Remove dpdk submodule [RH git: fd8549da9d]
    You probably also wants to do:
    
    git submodule deinit -f dpdk
    rm -rf .git/modules/dpdk


* Tue Jan 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-43
- Merging upstream branch-3.2 [RH git: cdde3a7096]
    Commit list:
    946d5ef01e vconn: Count vconn_sent regardless of log level.
    7a307b3563 backtrace: Fix error in log_backtrace() documentation.
    ab08bffa32 ovsdb: trigger: Do not allow conversion in read-only mode.
    4e74ac6da1 ovsdb: jsonrpc-server: Fix the DSCP value in default options.
    04fec86f7a jsonrpc: Sort JSON objects while printing debug messages.
    c4d655bc12 tests: ovsdb: Use diff -up format for replay test.
    4279901afe ovsdb-server.at: Enbale debug logs in active-backup tests.
    8583cdb990 ovsdb: transaction: Don't try to diff unchanged columns.
    7d9662345d ovsdb: transaction: Avoid diffs for different type references.
    abf5ec4109 ovsdb: Fix incorrect sharing of UUID and _version columns.


* Tue Jan 09 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-42
- Merging upstream branch-3.2 [RH git: 37c4409b08]
    Commit list:
    a3a05b7109 ci: Update the GitHub Ubuntu runner image to Ubuntu 22.04.


* Thu Jan 04 2024 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-41
- Merging upstream branch-3.2 [RH git: 1304925041]
    Commit list:
    ec1d730163 ovsdb-idl: Preserve change_seqno when deleting rows.


* Tue Dec 19 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-40
- Merging dpdk submodule [RH git: 3a3bf9bf69]
    Commit list:
    42ed2ce550 Revert "net/iavf: fix abnormal disable HW interrupt"


* Thu Dec 07 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-39
- Merging upstream branch-3.2 [RH git: 86d14e32a7]
    Commit list:
    36022655de system-dpdk: Wait for MTU changes to be applied.


* Tue Dec 05 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-38
- Merging upstream branch-3.2 [RH git: e156ad8e70]
    Commit list:
    c1ee47eb68 tunnel: Do not carry source port from a previous tunnel.
    74626ad6bb netdev-offload-tc: Fix offload of tunnel key tp_src.
    a49ebed1c4 ofp-ct: Return error for unknown property in CT flush.


* Fri Dec 01 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-37
- Merging upstream branch-3.2 [RH git: 32acf50ac9]
    Commit list:
    57916a78a8 cirrus: Update from FreeBSD 12 to 14.


* Fri Dec 01 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-36
- Merging dpdk submodule [RH git: 92d950c6f8]
    Commit list:
    db913c25d3 Merge tag 'v22.11.3' into 22.11
    b721cba875 Revert "net/i40e: revert link status check on device start"
    7849366693 version: 22.11.3
    774466c6dc Revert "net/iavf: fix tunnel TSO path selection"
    5e87ad0cf8 version: 22.11.3-rc1
    9fb53245ea common/cnxk: fix CPT backpressure disable on LBK
    17fef613a1 net/nfp: fix offloading flows
    338d0d589a net/nfp: fix Tx descriptor free logic of NFD3
    6c779801be test/bonding: fix include of standard header
    22c3a016bb net/ngbe: fix RSS offload capability
    fc56ce5a01 net/mana: fix Tx queue statistics
    50dc477c2e doc: fix link to flow capabilities from bnxt guide
    56e6c7ef88 doc: update BIOS settings and supported HW for NTB
    89a839ade5 doc: fix description of runtime directories
    b5513f8e84 doc: improve wording of cuda guide
    1a4aa1d333 doc: add flow template API requirements for mlx5
    75a8d9b6d9 app/testpmd: fix meter mark handle update
    4b42c698a2 net/mlx5: fix handle validation for meter mark
    6b686c0912 net/mlx5: fix validation for conntrack indirect action
    5cf1399e93 net/mlx5: fix MPRQ stride size for headroom
    2e3420f544 net/mlx5: fix LRO TCP checksum
    8397c9086a net/mlx5: fix drop action memory leak
    e6365bd3d2 net/e1000: fix Rx and Tx queue status
    4e200ede54 net/igc: fix Rx and Tx queue status
    4cae890867 net/ixgbe: fix Rx and Tx queue status
    912704eee5 common/iavf: fix MAC type for 710 NIC
    ca8c2ad458 net/iavf: fix stop ordering
    0a1fa750bc net/i40e: fix comments
    cb30cddab7 doc: fix typos and wording in flow API guide
    c12b2943c9 devtools: fix bashism in mailmap check
    0192d0ac53 kni: fix build with Linux 6.5
    44632490d9 examples/l3fwd: fix duplicate expression for default nexthop
    d385831f49 ipsec: fix NAT-T header length
    93d999a062 examples/ipsec-secgw: fix TAP default MAC address
    1fad66d244 examples/ipsec-secgw: fix socket ID default value
    76422de830 app/crypto-perf: fix socket ID default value
    1a98004f93 cryptodev: fix device socket ID type
    900b4ca132 examples/fips_validation: fix digest length in AES-GCM
    31daa7382f test/crypto: fix PDCP-SDAP test vectors
    440e528ae5 common/qat: detach crypto from compress build
    2e8f88824d crypto/qat: fix null algorithm digest placement
    64db6b40e9 baseband/fpga_5gnr_fec: fix starting unconfigured queue
    4325aff0d4 baseband/fpga_5gnr_fec: fix possible division by zero
    5ff397c56f net/ice: fix RSS hash key generation
    9b7215f150 net/iavf: fix tunnel TSO path selection
    35e69229eb net/ice: fix 32-bit build
    90a0f328b8 net/iavf: fix VLAN insertion in vector path
    c14d373562 net/ice: fix VLAN mode parser
    16ce632452 net/mlx5: fix query for NIC flow capability
    d165bff7dc net/mlx5: fix RSS expansion inner buffer overflow
    6a567b41ed net/mlx5: forbid MPRQ restart
    03e279ee8b net/mlx5: fix flow workspace destruction
    b5075ab2f9 net/mlx5: reduce counter pool name length
    b74fa83cf2 net/mlx5: fix profile check of meter mark
    db32b39aad common/mlx5: fix obtaining IB device in LAG mode
    fcf46d9c1d net/mlx5: fix error in VLAN actions creation
    0c50d16325 net/mlx5: fix error set for age pool initialization
    77159a5063 net/mlx5: fix error set in control tables create
    aa9f4b4c58 net/mlx5: fix return value of vport action
    d8ec0d83dd net/mlx5: fix error set in Tx representor tagging
    d3457cd43d net/mlx5: fix flow dump for modify field
    a944f7e99c ethdev: fix potential leak in PCI probing helper
    b6025f7a95 net/hns3: fix index to look up table in NEON Rx
    a2dc813bc4 net/mana: fix WQE count for ringing RQ doorbell
    9d30178ddd net/mana: fix counter overflow for posted WQE
    92d3673001 app/testpmd: fix flow rule number parsing
    36791bbc4b net/hns3: fix non-zero weight for disabled TC
    56b89656df app/testpmd: revert primary process polling all queues fix
    09d8d1fe4f net/txgbe: fix blocking system events
    7a44cac46c doc: fix number of leading spaces in hns3 guide
    8b5633f1e2 doc: fix syntax in hns3 guide
    ece673c7a1 doc: fix kernel patch link in hns3 guide
    9b9ae1aff1 net/hns3: delete duplicate macro definition
    3a935374f2 app/testpmd: fix checksum engine with GTP on 32-bit
    67912c46f4 net/netvsc: fix sizeof calculation
    d5309394d1 member: fix PRNG seed reset in NitroSketch mode
    1db71d413e hash: fix reading unaligned bits in Toeplitz hash
    7e6b4e9d63 mem: fix memsegs exhausted message
    7a57c9edd6 fib: fix adding default route
    fc4be70ded devtools: fix mailmap check for parentheses
    90aa091a20 ipc: fix file descriptor leakage with unhandled messages
    008fdd0e07 raw/ntb: avoid disabling interrupt twice
    54182cce72 cryptodev: fix comments of modular operation parameters
    a60ddd6954 net/cnxk: fix flow queue index validation
    cd88b5ff39 net/cnxk: fix cookies check with security offload
    c98cf071f8 net/cnxk: flush SQ before configuring MTU
    dcd21e65bd common/mlx5: adjust fork call with new kernel API
    79310b1b61 net/mlx5: fix device removal event handling
    ce6b9b3772 net/mlx5: fix risk in NEON Rx descriptor read
    e149ea19c2 net/iavf: fix protocol agnostic offloading with big packets
    04de2b4a56 net/ice: fix protocol agnostic offloading with big packets
    15b67727ca net/ice: fix MAC type of E822 and E823
    a45102d324 net/e1000: fix queue number initialization
    4f26624221 net/i40e: fix tunnel packet Tx descriptor
    2bdeeb53da net/iavf: fix abnormal disable HW interrupt
    520330cbb1 common/idpf: fix memory leak on AVX512 Tx queue close
    00f8c02c41 net/ixgbe: add proper memory barriers in Rx
    c8b6f57dc4 net/ice: fix tunnel packet Tx descriptor
    8a0712739d net/iavf: fix VLAN offload with AVX512
    64c315b9e9 common/sfc_efx/base: fix Rx queue without RSS hash prefix
    47326eff66 net/nfp: fix address always related with PF ID 0
    715143b51e net/nfp: fix representor name too long
    16a82d0d1a app/testpmd: fix primary process not polling all queues
    368138b61b net/ngbe: remove redundant codes
    e66f9e3fdf net/ngbe: fix link status in no LSC mode
    1c7e19d4a0 net/ngbe: adapt to MNG veto bit setting
    c523de9115 net/ngbe: fix extended statistics
    409cd85a16 net/txgbe: fix extended statistics
    19c8a701a7 net/txgbe: fix to set autoneg for 1G speed
    57b3a57dfa net/txgbe: adapt to MNG veto bit setting
    a62297801c net/txgbe: fix interrupt enable mask
    d96c0259e7 net/txgbe/base: fix Tx with fiber hotplug
    ff476852e7 net/bonding: fix destroy dedicated queues flow
    c193423238 net/bonding: fix startup when NUMA is not supported
    00d2dc7c42 net/nfp: fix VNI of IPv6 NVGRE encap action
    7797d05cd9 net/nfp: fix VNI of IPv4 NVGRE encap action
    dc6adc599c net/nfp: fix VNI of VXLAN encap action
    fa5f6cff44 ethdev: update documentation for API to get FEC
    7594b6e44d ethdev: check that at least one FEC mode is specified
    ff56bf6f3a ethdev: update documentation for API to set FEC
    c25e954265 net/nfp: fix endian conversion for tunnel decap action
    502acb0f83 net/nfp: fix unneeded endian conversion
    a526063092 net/nfp: fix IPv6 address for set flow action
    64839553ee test/security: fix event inline IPsec reassembly tests
    643423f0b7 crypto/openssl: skip workaround at compilation time
    91085d3b58 crypto/openssl: fix memory leak in auth processing
    981792ebc4 crypto/qat: fix sym device prototype
    791a0227d2 common/qat: fix command parameter corruption
    0d5c3e03c5 ci: fix libabigail cache in GHA
    ef98a4da59 mbuf: fix Doxygen comment of distributor metadata
    5887a7d14d test: add graph tests
    2bdfd0d7ba examples/fips_validation: fix external build
    72c87f820d examples/l2fwd-cat: fix external build
    11757d12ee dma/dpaa2: set VFA bit for route-by-port with VF
    9047d5c9bf doc: remove warning with Doxygen 1.9.7
    d8e35e7efe doc: fix typo in graph guide
    55fbb9de8d test/mbuf: fix crash in a forked process
    4d116ff1ac net/iavf: fix virtchnl command called in interrupt
    bd5c63549a net/ice: fix outer UDP checksum offload
    bae61d2305 net/ice: initialize parser for double VLAN
    1f35681b6e net/ice: fix timestamp enabling
    3b032bbf78 net/ice: adjust timestamp mbuf register
    1d71b68237 net/ice/base: remove unreachable code
    7691c220b6 net/ice/base: fix incorrect defines for DCBx
    4ec6da600e net/ice: fix DCF control thread crash
    c4d749115d net/iavf: release large VF when closing device
    21ec365e75 net/ice: fix DCF RSS initialization
    83ad87933a net/ice: fix statistics
    b9f3b81e9e common/idpf/base: fix memory leaks on control queue
    1b04a2f618 common/idpf/base: fix parameters when send msg to cp
    e5868f6648 common/idpf/base: fix ITR register definitions for AVF
    4cc85337b3 common/idpf/base: fix control queue send and receive
    1bfcca5b65 common/idpf: remove device stop flag
    c86c1efd2f net/idpf: fix Rx data buffer size
    78c374bf41 net/iavf: fix Rx data buffer size
    1f9af08714 net/ice: fix Rx data buffer size
    7a72db6add net/i40e: fix Rx data buffer size
    65303f7c26 doc: fix typo in cnxk platform guide
    d9ba8a4251 net/qede: fix RSS indirection table initialization
    df11a52e33 common/cnxk: fix receive queue with multiple mask
    6cbb5fc911 common/cnxk: fix inline device VF identification
    d0f357fb6e common/cnxk: fix uninitialized pointer read
    103a33d02d common/cnxk: fix setting channel mask for SDP interfaces
    c1e167a078 event/cnxk: fix mempool cookies check
    338514e558 event/cnxk: fix Tx adapter data pointer
    46d6c05770 common/cnxk: fix IPsec IPv6 tunnel address byte swap
    9d1dbc6a01 mempool/cnxk: avoid hang when counting batch allocs
    255fcff79e net/mlx5: fix drop action attribute validation
    b53417d63b net/mlx5: fix duplicated tag index matching in SWS
    124a919b4e net/mlx5: forbid duplicated tag index in pattern template
    eb02902423 net/mlx5: fix VXLAN matching with zero value
    2e6f71cb51 net/mlx5: fix matcher layout size calculation
    9015baea29 net/mlx5: enhance error log for tunnel offloading
    2a45186cf4 net/virtio-user: fix leak when initialisation fails
    d228fa562b net/virtio: fix initialization to return negative errno
    a43f6d459a net/virtio: propagate interrupt configuration error values
    94bed3c2fa vhost: fix invalid call FD handling
    fe3e1fc9d8 vhost: fix notification stats for packed ring
    3a5561e8b5 crypto/ipsec_mb: optimize allocation in session
    a659f5f18c test/crypto: fix IPsec AES CCM vector
    7e0080ff4f crypto/cnxk: fix IPsec CCM capabilities
    c53467f356 crypto/ipsec_mb: fix enqueue counter for SNOW3G
    d2e09fc0fc test/crypto: fix session creation check
    e3456f2478 crypto/openssl: fix memory free
    48b48d2ba8 cryptodev: clarify error codes for symmetric session
    400a3302de examples/ipsec-secgw: fix zero address in ethernet header
    6217afd84c test/crypto: fix return value for SNOW3G
    228857a34c crypto/scheduler: fix last element for valid args
    4413744138 crypto/qat: fix stack buffer overflow in SGL loop
    0af5332dff doc: fix auth algos in cryptoperf app
    3a8502c73d net/vmxnet3: fix return code in initializing
    c40b9a9873 net/nfp: fix TP flow action for UDP
    74870817fb net/nfp: fix flow hash table creation
    18493825d1 net/nfp: fix representor creation
    de78bd45d6 net/nfp: fix control mempool creation
    caa96e94b0 net/nfp: fix TOS of IPv6 NVGRE encap flow action
    67544106ac net/nfp: fix TOS of IPv6 GENEVE encap flow action
    c81816d07f net/nfp: fix TOS of IPv6 VXLAN encap flow action
    a1d864c39b net/nfp: fix IPv6 flow item
    aae5fcb267 net/nfp: fix disabling promiscuous mode
    e659a163e3 ethdev: fix calloc arguments
    175e7a7bac net/hns3: fix IMP reset trigger
    219305d227 net/hns3: fix redundant line break in log
    4292ebcef4 net/hns3: fix inaccurate log
    1c81e1a0a8 net/hns3: fix uninitialized variable
    f99fa19b60 net/hns3: fix device start return value
    19c20cef27 net/hns3: fix mbuf leakage when RxQ started after reset
    e9ade95ac4 net/hns3: fix mbuf leakage when RxQ started during reset
    422a5e09d2 net/hns3: extract PTP to its own header file
    a8ad010661 net/hns3: uninitialize PTP
    3999b58cd3 net/hns3: fix RTC time after reset
    69bff6ea1c net/hns3: fix RTC time on initialization
    bdf2131156 doc: fix format in flow API guide
    9ca1814402 net/hns3: fix missing FEC capability
    340cb03d7f net/hns3: fix FEC mode check
    b048cdca82 net/hns3: fix FEC mode for 200G ports
    a678d7da2b ethdev: fix indirect action conversion
    d859368e8f net/hns3: fix Rx multiple firmware reset interrupts
    f2dd43a6e9 net/hns3: fix variable type mismatch
    2a7aef1dd0 net/hns3: fix never set MAC flow control
    88cf99ed01 net/sfc: invalidate dangling MAE flow action FW resource IDs
    3254062488 net/mana: return probing failure if no device found
    631f57f5ef ethdev: fix MAC address occupies two entries
    32e0eaa22b net/txgbe: fix use-after-free on remove
    799cc0612c net/vmxnet3: fix drop of empty segments in Tx
    acbaa6bb5d net/nfp: fix VLAN push flow action
    9d1fbdb584 app/testpmd: fix GTP L2 length in checksum engine
    e7e0590338 net/dpaa2: fix checksum good flags
    ecd3e1f354 net/mana: optimize completion queue by batch processing
    5b1a78987f net/mana: avoid unnecessary assignments in data path
    753a735ea0 net/mana: use datapath logging
    8e27036b63 net/tap: set locally administered bit for fixed MAC address
    bd14912ab4 net/sfc: stop misuse of Rx ingress m-port metadata on EF100
    a1dfa52406 net/hns3: fix build warning
    10a2ee0333 eal/linux: fix legacy mem init with many segments
    f4d5f30fe4 eal/linux: fix secondary process crash for mp hotplug requests
    53e6b8c3f0 event/cnxk: fix nanoseconds to ticks conversion
    cf79458fad eventdev/timer: fix buffer flush
    d3f784ad5f event/cnxk: fix setting attributes in empty get work
    d0257dc168 event/dsw: free rings on close
    c12daa6d2d doc: fix event timer adapter guide
    ca72f7fdba eventdev/timer: fix timeout event wait behavior
    5ecf2e459d eal/x86: improve multiple of 64 bytes memcpy performance
    f4ccd39056 pci: fix comment referencing renamed function
    c3b5322fc3 build: fix warning when getting NUMA nodes
    44a9b3b4f7 ci: fix build for Arm cross compilation in GHA
    94babf61c5 eal: avoid calling cleanup twice
    6413085d5f test/malloc: fix statistics checks
    37e859deb8 test/malloc: fix missing free
    2d3c4df8f5 pipeline: fix double free for table stats
    cada66aff2 ring: fix dequeue parameter name
    57dd0e53b1 telemetry: fix autotest on Alpine
    f14b25d925 kernel/freebsd: fix function parameter list
    47da400295 vfio: fix include with musl runtime
    8742732344 ring: fix use after free
    f9a20a28ec examples/ntb: fix build with GCC 13
    28aa181578 examples/ip_pipeline: fix build with GCC 13
    156b423f54 kni: fix build with Linux 6.3
    403d133d7f net: fix return type of IPv4 L4 packet checksum
    d75b66ad1c version: 22.11.2
    8edef444c7 build: detect backtrace availability
    aa96e66c9a version: 22.11.2-rc1
    9dcf799d88 common/mlx5: use just sufficient barrier for Arm
    6940159325 net/mlx5/hws: fix IPv4 fragment matching
    f567b1ee98 common/cnxk: fix IPv6 extension header parsing
    f9f94070e0 doc: fix DCF instructions in ice guide
    d4dc7b1d1b doc: add Linux capability to access physical addresses
    7ac4d1cebf doc: fix pipeline example path in user guide
    abf5150780 devtools: move mailmap check after patch applied
    0dce56b788 acl: fix crash on PPC64 with GCC 11
    ac849cac65 pdump: fix build with GCC 12
    fcf7e0e6f7 test/crypto: fix statistics error messages
    95c2df95d2 doc: fix code blocks in cryptodev guide
    2fe7fcc1a3 net/mlx5: fix sysfs port name translation
    80ec04827f net/mlx5: fix CQE dump for Tx
    1f4de71406 net/mlx5/hws: fix error code of send queue action
    644bcdb856 net/mlx5: fix build with GCC 12 and ASan
    d4335766d4 net/mlx5/hws: fix pattern creation
    1cbb884f35 app/testpmd: fix encap/decap size calculation
    6a3a2809eb examples/qos_sched: fix config entries in wrong sections
    782eda8807 net/ipn3ke: fix representor name
    abe24f4bd0 net/ipn3ke: fix thread exit
    3bdf07e682 bus/ifpga: fix devargs handling
    0680a33bc7 net/mlx5: fix isolated mode if no representor matching
    e10c220053 net/mlx5: fix egress group translation in HWS
    3f7e967684 doc: fix LPM support in l3forward guide
    003a860c86 examples/l3fwd: remove hash entry number
    e528b4f96c net/mlx5: fix hairpin Tx queue reference count
    b836bb43cf net/iavf: fix device stop during reset
    158c05028f net/idpf: reset queue flag when queue is stopped
    8cb2ee860c net/i40e: fix MAC loopback on X722
    8cc24b8aab net/e1000: fix saving of stripped VLAN TCI
    91a60dfeee net/i40e: fix AVX512 fast-free path
    8a6d064801 net/sfc: invalidate switch port entry on representor unplug
    d59d4fbffa net/virtio: remove address width limit for modern devices
    7be8e75277 net/vhost: fix Rx interrupt
    1ecf04df54 net/vhost: fix leak in interrupt handle setup
    9736b58d62 net/vhost: add missing newline in logs
    b80c949b77 app/bbdev: check statistics failure
    39ca0f7397 crypto/ipsec_mb: relax multi-process requirement
    6919a8d874 app/compress-perf: fix remaining data for ops
    dc6e5405ca test/crypto: fix skip condition for CPU crypto SGL
    58dff4134c test/crypto: fix capability check for ZUC cipher-auth
    0217458d5e test/crypto: fix ZUC digest length in comparison
    7d3df2701d app/testpmd: fix interactive mode on Windows
    ef700bf7d0 gpudev: export header file for external drivers
    db12268a95 eal/unix: fix thread creation
    29cdc2b88f test/mbuf: fix test with mbuf debug enabled
    64f4cb8bce test: fix segment length in packet generator
    8f35765d15 reorder: fix sequence number mbuf field register
    38369a1974 ring: silence GCC 12 warnings
    ebcd68e43a raw/skeleton: fix selftest
    8160c206ca examples/ipsec-secgw: fix offload variable init
    55f236de5c app/flow-perf: fix division or module by zero
    161ef7c943 app/crypto-perf: fix test file memory leak
    72c1da7b2d crypto/openssl: fix freeing in RSA EVP
    1536a7304a crypto/qat: fix SM3 auth mode
    eba4eee77b crypto/ccp: fix PCI probing
    f081724c6b net/mlx5: fix Windows build with MinGW GCC 12
    5af10c2a20 net/hns3: add verification of RSS types
    3a5105f1de net/hns3: reimplement hash flow function
    7307f96575 net/hns3: separate flow RSS config from RSS conf
    796c8188a5 net/hns3: allow adding queue buffer size hash rule
    adf239587c net/hns3: save hash algo to RSS filter list node
    fc620e6832 net/hns3: use new RSS rule to configure hardware
    a2804bcc0c net/hns3: separate setting and clearing RSS rule
    679028a2ee net/hns3: separate setting RSS types
    3b85ef547e net/hns3: separate setting redirection table
    99c75dbbfe net/hns3: separate setting hash key
    9c24ae1b2d net/hns3: separate setting hash algorithm
    dde9ec15ea net/hns3: use hardware config to report redirection table
    dbcf64d12e net/hns3: use hardware config to report hash types
    68da0b3986 net/hns3: use hardware config to report hash key
    5042fd8459 net/hns3: fix possible truncation of redirection table
    81fbc0298c net/hns3: fix possible truncation of hash key when config
    73b11178a3 mem: fix heap ID in telemetry
    57294e8df4 app/testpmd: cleanup cleanly from signal
    564dbb6a03 cmdline: handle EOF as quit
    1a22081244 cmdline: make rdline status not private
    09b626852e kni: fix possible starvation when mbufs are exhausted
    993c0d08eb net/sfc: fix resetting mark in tunnel offload switch rules
    f6bdbdf6f2 common/sfc_efx/base: add MAE mark reset action
    4224d5f521 regex/mlx5: fix doorbell record
    b5512d3186 regex/mlx5: utilize all available queue pairs
    cb4baf72a4 table: fix action selector group size log2 setting
    60f6d9449c raw/skeleton: fix empty devargs parsing
    0848681e90 dma/skeleton: fix empty devargs parsing
    ce3c0aa7aa net/virtio: fix empty devargs parsing
    33b1cea25d net/hns3: fix empty devargs parsing
    63ba1d9f2c cryptodev: fix empty devargs parsing
    00e3a4efbc compressdev: fix empty devargs parsing
    6567e0cf76 kvargs: add API documentation for process callback
    bb296faffc net/nfp: fix MTU configuration order
    bf878ca704 eal/windows: fix thread creation
    fac8d80e0d common/cnxk: add memory clobber to steor and ldeor
    67479d24a4 net/cnxk: fix LBK BPID usage
    14688b03c0 net/ice: fix Rx timestamp
    8ec56c115a net/i40e: fix maximum frame size configuration
    287a57f832 net/i40e: revert link status check on device start
    dc67b490e8 net/ixgbe: fix IPv6 mask in flow director
    b0901e6d5b app/testpmd: fix secondary process packet forwarding
    17637f9c0f net/nfp: fix offload of multiple output actions
    fc325877f6 net/nfp: fix set DSCP flow action
    336d6c1c41 net/nfp: fix set TTL flow action
    264cbadbee net/nfp: fix set TP flow action
    dcc0be2c8a net/nfp: fix set IPv6 flow action
    d6fb8fc9c1 net/nfp: fix set IPv4 flow action
    a0a1f437b2 net/nfp: fix set MAC flow action
    aaa501436c ethdev: remove telemetry Rx mbuf alloc failed field
    03cfac3c99 net/nfp: fix getting RSS configuration
    5475d251f1 net/mana: fix stats counters
    00af2661ac ethdev: fix build with LTO
    cd2635a2b5 app/testpmd: fix packet transmission in noisy VNF engine
    e8996dc08d app/testpmd: fix packet count in IEEE 1588 engine
    a4141026d7 app/testpmd: fix Tx preparation in checksum engine
    62324129c1 net/mana: enable driver by default
    64d858dc03 net/gve: fix offloading capability
    90f12bb74f net/nfp: fix 48-bit DMA support for NFDk
    6ede2ab472 common/cnxk: fix auth key length
    995a6460b2 examples/fips_validation: add extra space in JSON buffer
    903f4ee07d examples/fips_validation: fix AES-XTS sequence number
    91c80e936a examples/fips_validation: fix AES-GCM tests
    809de506c9 examples/fips_validation: fix integer parsing
    ac87a06f6b examples/fips_validation: fix MCT output for SHA
    435188c3c4 compress/mlx5: fix queue setup for partial transformations
    2a091b2f31 compress/mlx5: fix output Adler-32 checksum offset
    9d7902bf42 compress/mlx5: fix decompress xform validation
    2bf416240d examples/ipsec-secgw: fix auth IV length
    33f3ef5021 net/virtio: deduce IP length for TSO checksum
    950227315b vhost: fix OOB access for invalid vhost ID
    a6d0c8f6aa vhost: fix slot index in async split virtqueue Tx
    47cef65600 test/bbdev: remove check for invalid opaque data
    dccdf95daa test/bbdev: extend HARQ tolerance
    cdfa1794a6 test/bbdev: fix crash for non supported HARQ length
    4bdaf50031 baseband/acc: fix check after deref and dead code
    bf521b9f80 baseband/acc: fix iteration counter in TB mode
    ff4d7c9a71 baseband/acc: prevent to dequeue more than requested
    6c9f6f15ee baseband/acc: add explicit mbuf append for soft output
    63797158c2 baseband/acc: protect from TB negative scenario
    f76551552e eventdev: fix memory size for telemetry
    2f9bb3f72a event/cnxk: fix SSO cleanup
    0a3f30f07c doc: fix reference to event timer header
    e806f0529d doc: add gpudev to the Doxygen index
    300d83b989 eal/windows: fix pedantic build
    03299eb5d4 net/mlx5: fix crash on action template failure
    4dc4547f2d common/cnxk: fix second pass flow rule layer type
    dc7302e733 examples/qos_sched: fix Tx port config when link down
    ecb065fe53 examples/cmdline: fix build with GCC 12
    1b93563378 eal: use same atomic intrinsics for GCC and clang
    a5d83cee8e build: fix toolchain definition
    15ae43b33a test/reorder: fix double free of drained buffers
    b515c436e6 reorder: invalidate buffer from ready queue in drain
    106e0f2637 dma/ioat: fix error reporting on restart
    90ad21e988 dma/ioat: fix indexes after restart
    881919396f dma/ioat: fix device stop if no copies done
    fb395ef1d0 eal/freebsd: fix lock in alarm callback
    a656595e9b sched: fix alignment of structs in subport
    38465cec0a app/testpmd: fix crash on cleanup
    31f4d9ce13 net/nfp: restrict flow flush to the port
    7ae80e1379 net/nfp: fix VNI of VXLAN encap action
    8cdbec0d75 net/bnxt: fix link state change interrupt config
    fd1ff4fecb common/cnxk: fix channel mask for SDP interfaces
    ad62d3f410 app/compress-perf: fix testing single operation
    17f4281693 app/compress-perf: fix some typos
    c028045915 net/iavf: fix VLAN offload with AVX2
    3c047b3d86 net/ixgbe: enable IPv6 mask in flow rules
    79781cd646 net/iavf: fix building data desc
    644d38523a net/iavf: protect insertion in flow list
    e13bcf7645 net/ice: fix validation of flow transfer attribute
    199591d8d1 net/i40e: fix validation of flow transfer attribute
    5aacd2a62c net/iavf: add lock for VF commands
    dbe54bfd9b net/ixgbe: fix firmware version consistency
    bfa9955652 net/idpf: fix driver infos
    96ccb4c287 net/idpf: fix mbuf leak in split Tx
    489ddd71b3 net/i40e: reduce interrupt interval in multi-driver mode
    6e50af124f net/iavf: fix outer UDP checksum offload
    4c6cddb596 net/mlx5: check compressed CQE opcode in vectorized Rx
    547b239a21 net/mlx5: ignore non-critical syndromes for Rx queue
    47f5a0e5f3 net/mlx5: fix error CQE dumping for vectorized Rx
    9e0308d5ef net/mlx5/hws: fix memory leak on general pool DB init
    394ba3cfc4 net/mlx5: fix read device clock in real time mode
    35eadc22bc net/mlx5: fix warning for Tx scheduling option
    a04fa37e6e net/mlx5: fix wait descriptor opcode for ConnectX-7
    d5be082621 net/mlx5: fix flow sample with ConnectX-5
    575cfce6a7 common/mlx5: fix offset of a field
    f3282a003f common/mlx5: improve AES-XTS tweak capability check
    4434048bbe net/mlx5: fix GENEVE resource overwrite
    dcb16c48e0 net/mlx5: fix available tag registers calculation for HWS
    a93bb50b6c net/txgbe: fix Rx buffer size in config register
    3a842fbbb7 net/sfc: enforce fate action in transfer flow rules
    be7d6baf28 net/sfc: fix MAC address entry leak in transfer flow parsing
    56789776c6 net/hns3: extract common functions to set Rx/Tx
    13f062ec55 net/hns3: make getting Tx function static
    1df48cce5e net/hns3: separate Tx prepare from getting Tx function
    418d6cbc35 net/hns3: remove debug condition for Tx prepare
    873d6edb18 net/hns3: add debug info for Rx/Tx dummy function
    c6b36e8183 net/hns3: fix burst mode query with dummy function
    6c9834cd2a net/nfp: fix max DMA length
    f418af17fc app/testpmd: fix link check condition on port start
    e4f7453ec1 net/sfc: export pick transfer proxy callback to representors
    6ae7e4345e net/hns3: fix duplicate RSS rule check
    5c129d8898 net/hns3: fix config struct used for conversion
    f2de3c967d net/hns3: fix warning on flush or destroy rule
    2e99d819d3 net/hns3: remove useless code when destroy valid RSS rule
    d45c8fe415 net/hns3: use RSS filter list to check duplicated rule
    93fa374ce4 net/hns3: fix clearing RSS configuration
    9126ed75be net/hns3: fix RSS key size compatibility
    36d6105f51 net/hns3: refactor set RSS hash algorithm and key interface
    14d988ad25 net/hns3: extract common function to query device
    ffc3022e2d net/hns3: fix log about indirection table size
    547a2c7a55 net/txgbe: fix interrupt loss
    c22430a6e5 net/ngbe: add spinlock protection on YT PHY
    767d609db7 net/ngbe: fix packet type to parse from offload flags
    c96c4e1b9e net/txgbe: fix packet type to parse from offload flags
    e7149d390b net/txgbe: fix default signal quality value for KX/KX4
    a1d3811bc0 app/testpmd: fix forwarding stats for Tx dropped
    8eefe1d245 doc: fix description of L2TPV2 flow item
    5876103dd2 net/hns3: declare flow rule keeping capability
    58910572e8 net/virtio-user: fix device starting failure handling
    78d828c247 vhost: fix possible FD leaks on truncation
    eab1940f97 vhost: fix possible FD leaks
    cf313170bf vhost: decrease log level for unimplemented requests
    0772cc1d89 eal: cleanup alarm and hotplug before memory detach
    f7825956c0 eventdev/timer: fix overflow
    fd3e2fb617 test/mbuf: fix mbuf reset test
    cc69b3523e drivers/bus: fix leak for devices without driver
    acacb53810 eal/linux: fix hugetlbfs sub-directories discovery
    0343d4cb72 telemetry: fix repeat display when callback don't init dict
    f5803ba5c5 raw/ifpga/base: fix init with multi-process
    08019befc3 mem: fix hugepage info mapping
    23cb90427a net/cnxk: validate RED threshold config
    d7d670cbe2 common/cnxk: reduce channel count per LMAC
    4060bba354 common/cnxk: fix IPv6 extension matching
    5444957e57 common/cnxk: fix dual VLAN parsing
    f40c4f3e0b net/cnxk: fix deadlock in security session creation
    78c0d2ab85 common/cnxk: fix aura ID handling
    87725aa6d2 net/cnxk: fix packet type for IPv6 packets post decryption
    efb6eccf8e event/cnxk: fix timer operations in secondary process
    903d4a18a1 event/cnxk: fix burst timer arm
    77f50c0971 eventdev/eth_rx: fix getting adapter instance
    0a78560065 event/cnxk: wait for CPT flow control on WQE path
    5e9f154f81 eventdev/crypto: fix function symbol export
    48870212ad doc: fix firmware list in bnxt guide
    a4d58197b2 net/bnxt: fix RSS hash in mbuf
    3f1568d969 net/bnxt: fix Rx queue stats after queue stop and start
    bc1682ee55 net/bnxt: fix Tx queue stats after queue stop and start
    d357ef8a3c crypto/ipsec_mb: fix ZUC-256 maximum tag length
    031b48d670 compressdev: fix end of driver list
    ce54658be7 cryptodev: fix sym session mempool creation description
    cbd714b1f9 test/crypto: add missing MAC-I to PDCP vectors
    ca39bc2337 test/crypto: fix typo in AES test
    11f862d605 crypto/ipsec_mb: remove unnecessary null check
    24dc362291 crypto/openssl: fix warning on copy length
    2d28201221 crypto/ccp: fix IOVA handling
    f11d779c24 crypto/ccp: remove some dead code for UIO
    4e76b62756 crypto/ccp: remove some printf
    f3d0a011e3 baseband/acc: fix acc100 queue mapping to 64 bits
    8f06dfc381 baseband/acc: fix multiplexing acc100 operations
    3c330a28d7 baseband/acc: fix acc100 iteration counter in TB
    f770622597 baseband/acc: fix memory leak on acc100 close
    e44360ae85 app/bbdev: add allocation checks
    9f13ab03f6 app/bbdev: fix build with optional flag
    1e82bbe91d app/bbdev: fix build with optional flag
    be1187e1a6 vhost: fix net header settings in datapath
    72820dd60f vdpa/ifc: fix reconnection in SW-assisted live migration
    a347909ae2 vdpa/ifc: fix argument compatibility check
    ab2779057e build: fix dependencies lookup
    573de4f522 app/dumpcap: fix storing port identifier
    cb3c0ba47e examples/qos_sched: fix debug mode
    0e846591b5 mem: fix telemetry data truncation
    453a4d30ed cryptodev: fix telemetry data truncation
    16f272c96f mempool: fix telemetry data truncation
    bd11b88f8b ethdev: fix telemetry data truncation
    4f9c6db77b telemetry: move include after guard
    8ab731497d app/testpmd: fix interactive mode with no ports
    1df8c20923 net/nfp: fix teardown of flows sharing a mask ID
    375086efb5 net/nfp: store counter reset before zeroing flow query
    58db4361dc net/hns3: fix inaccurate RTC time to read
    36ec039309 net/ena: fix deadlock in RSS RETA update
    f029ceb7aa net/nfp: fix firmware name derived from PCI name
    a87a84560c net/nfp: fix Tx packet drop for large data length
    5ef77a1221 graph: fix node shrink
    b9a14f6737 gpudev: fix deadlocks when registering callback
    1586e3b7bc fbarray: fix metadata dump
    23a5b25c8a bus/fslmc: fix deadlock on MC send command timeout
    a0b1faaad2 crypto/qat: fix build
    a636c94996 crypto/qat: fix build for generic x86 with GCC 12
    b527b4c168 crypto/qat: fix stream cipher direction
    e2c05f4621 examples/l2fwd-event: fix worker cleanup
    478bec21d0 eventdev/eth_tx: fix devices loop
    4c388e80e9 eventdev/crypto: fix failed events
    ddaec3cd54 eventdev/crypto: fix overflow in circular buffer
    e1ca28205f eventdev/crypto: fix offset used while flushing events
    d66216823d eventdev/crypto: fix enqueue count
    b81247d47b app/crypto-perf: fix IPsec direction
    683ce01b19 app/crypto-perf: fix SPI zero
    bbba565c73 app/crypto-perf: fix session freeing
    a932cd545f app/crypto-perf: fix number of segments
    193ff405b3 crypto/cnxk: fix digest for empty input data
    a996e9816f devtools: fix escaped space in grep pattern
    b6d9ddee2c doc: fix dependency setup in l2fwd-cat example guide
    760cf7543c hash: fix GFNI implementation build with GCC 12
    c8af2a4ad5 kni: fix build on RHEL 9.1
    fc98f9c6d7 eal/windows: mark memory config as complete
    c12e76d298 devtools: fix name check with mbox files
    07e68b092c drivers: fix symbol exports when map is omitted


* Thu Nov 30 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-35
- Merging upstream branch-3.2 [RH git: 6879730533]
    Commit list:
    349e02766c dpdk: Use DPDK 22.11.3 release for OVS 3.2.


* Wed Nov 29 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-34
- Merging upstream branch-3.2 [RH git: d72ace5709]
    Commit list:
    a52d28b7e0 ovs-ofctl: Correctly mark the CT flush commands.


* Mon Nov 27 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-33
- Merging upstream branch-3.2 [RH git: d892f1b66a]
    Commit list:
    319a97e412 mcast-snooping: Flush flood and report ports when deleting interfaces.
    d7e9117ca3 mcast-snooping: Test per port explicit flooding.


* Wed Nov 01 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-32
- Merging upstream branch-3.2 [RH git: 109500e1ee]
    Commit list:
    0dd10cd803 flake8: Fix E721 check failures.
    c0275d6a16 build-aux: Enable flake8 checks for python extraction scripts.
    bc261b9597 build-aux/extract-ofp-msgs: Fix flake8 and syntax errors.
    8e50fc7935 build-aux/extract-ofp-fields: Fix flake8 and syntax errors.
    374a7bf631 build-aux/extract-ofp-errors: Fix flake8 and syntax errors.
    0634be9426 build-aux/extract-ofp-actions: Fix flake8 and syntax errors.
    e76ecab431 automake: Move build-aux EXTRA_DIST updates to their own file.


* Tue Oct 31 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-31
- Merging upstream branch-3.2 [RH git: d76eaaa84f]
    Commit list:
    1b0c75320d netdev-offload: Fix Clang's static analyzer 'Division by zero' warnings.
    3919e61a74 ofp-table: Fix count_common_prefix_run() function.
    07e3598da4 vswitch.xml: Add entry for dpdkvhostuser userspace-tso.
    afc9bad24f vswitch.xml: Add dpdkvhostuser group status.


* Fri Oct 27 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-30
- Merging upstream branch-3.2 [RH git: 26d7eed996]
    Commit list:
    dadbcdd835 readthedocs: Use dirhtml builder.


* Thu Oct 26 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-29
- Merging upstream branch-3.2 [RH git: 3bdcee0a22]
    Commit list:
    1cdc763883 tests: Use ping timeout instead of deadline.


* Wed Oct 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-28
- Merging upstream branch-3.2 [RH git: 88f58a44d2]
    Commit list:
    19770fc307 tests/system-traffic: Ensure no name resolution for tcpdump.


* Wed Oct 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-27
- Merging upstream branch-3.2 [RH git: cdbd4c8dfe]
    Commit list:
    9183518076 readthedocs: Add the configuration file.


* Fri Oct 20 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-26
- Merging upstream branch-3.2 [RH git: 7ed9e7e0ff]
    Commit list:
    f344aa0b52 tc: Improve logging of mismatched actions.
    159e214c3e ofproto-dpif-upcall: Pause revalidators when purging.
    40b55d2e90 db-ctl-base: Fix memory leak of db commands.


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-25
- README.rst: add git submodule update --init [RH git: 17107fb661]


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-24
- redhat: fix workaround by using the correct commit on ovs and dpdk [RH git: 4fa319d6fd]


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-23
- README.rst add --recurse-submodules to documentation [RH git: 1899b228fd]


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-22
- redhat: don't use tag, but commit directly in workaround [RH git: 53927e8262]
    This is needed since the tag is not accessible in jenkins


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-21
- Move redhat/README.rst to root and add a symlink into redhat [RH git: 81c9958b81]


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-20
- redhat: add a workaround to be sure the dpdk patch is correctly applied [RH git: 0a4f323ccc]
    This is needed since dpdk submodule was created on top of dpdk branch
    22.11 and not on top of v22.11.1.
    This commit can be reverted on the next ovs packages.


* Fri Oct 20 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-19
- Convert README.txt to rst [RH git: bb31afa02a]


* Tue Oct 17 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-18
- Merging upstream branch-3.2 [RH git: 40527bedef]
    Commit list:
    0ebd8cdbf7 Prepare for 3.2.2.
    cd5dee5b9d Set release date for 3.2.1.


* Wed Oct 11 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-17
- redhat: use rhpkg push instead of git push [RH git: 5bcbc4c7bc]


* Wed Oct 11 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-16
- redhat: fix applying patches [RH git: 78c86345d1]


* Tue Oct 10 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-15
- Merging upstream branch-3.2 [RH git: a8e307cc01]
    Commit list:
    0f7907a761 netdev-dpdk: Document rx-steering status options.
    99fa50391e netdev-dpdk: Update docs for interface info.
    af98a39f0b netdev-dpdk: Document status options for VF MAC address.


* Mon Oct 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-14
- Merging upstream branch-3.2 [RH git: c3521203af]
    Commit list:
    6cab4c6f92 netdev-offload-dpdk: Fix flushing of a physdev.


* Thu Oct 05 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-13
- Merging upstream branch-3.2 [RH git: da3d5bd50b]
    Commit list:
    a2c01c797b connmgr: Fix ofconn configuration on vswitchd startup.


* Mon Sep 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-12
- Merging upstream branch-3.2 [RH git: 0798b67699]
    Commit list:
    0d0e95cd2a ovsdb: Fix potential leak when making diff of conditions.


* Mon Sep 18 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-11
- Merging upstream branch-3.2 [RH git: c2edb93a92]
    Commit list:
    25f11d058a python: idl: Fix last-id update from a monitor reply.


* Sat Sep 09 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-10
- Merging upstream branch-3.2 [RH git: b964fa5bf0]
    Commit list:
    b5c08719e6 netlink-conntrack: Fix partial match of entries with SCTP. (#2228037)


* Fri Sep 08 2023 Timothy Redaelli <tredaelli@redhat.com> - 3.2.0-9
- redhat: fix merge script [RH git: 96dd34e20a]
    Update the script to work with ovs as a subtree and dpdk a submodule


* Wed Sep 06 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-8
- Merging upstream branch-3.2 [RH git: 2dce31703e]
    Commit list:
    00212562ea ofproto-dpif-xlate: Fix recirculation with patch port and controller. (#2170920)


* Wed Sep 06 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-7
- Merging upstream branch-3.2 [RH git: 74bbcf5cca]
    Commit list:
    0638b7b264 ofproto-dpif-xlate: Don't reinstall removed XC_LEARN rule. (#2213892)


* Wed Aug 30 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-6
- Merging upstream branch-3.2 [RH git: 086d5be77e]
    Commit list:
    1d78a3f316 netdev-dpdk: Disable net/tap Tx L4 checksum offloads.
    8612f8cced tests/mfex: Don't require python cryptography.
    cf537b2c43 configure: Avoid deprecated AC_PROG_CC_C99 if possible.


* Mon Aug 28 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-5
- Merging upstream branch-3.2 [RH git: a7e43327ab]
    Commit list:
    01dd0ab512 tests: Fix time dependency in overlapping flows modification test.


* Mon Aug 28 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-4
- Merging upstream branch-3.2 [RH git: df4af3fd41]
    Commit list:
    0df9f974dc netdev-dpdk: Clear IP packet type when no offload is requested. (#2231081)


* Fri Aug 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-3
- Merging upstream branch-3.2 [RH git: 6e99e930b6]
    Commit list:
    a4aa202513 python: Use build to generate PEP517 compatible archives.
    a8a31e6534 python: Use twine to upload sdist package to pypi.org.
    3b3a7b50fd python: Rename build related code to ovs_build_helpers.
    bf27c8b966 dpif-netdev: Fix length calculation of netdet_flow_key.
    74a64ac0a2 doc: Fix description of max_len for controller action.
    20f4645273 docs: Fix rendering of VLAN Comparison Chart.
    da20390c74 fatal-signal: Drop logging of failed dummy backtrace.


* Fri Aug 25 2023 Open vSwitch CI <ovs-ci@redhat.com> - 3.2.0-2
- Merging upstream branch-3.2 [RH git: 62c8b67317]
    Commit list:
    9448098338 docs: Run tbl preprocessor in manpage-check rule.
    e2163f2ed4 docs: Add `nowarn` region option to tables.
    4e6bc7674e tests: Add clang-analyzer-results to gitignore.
    55d01136a7 ci: Add jobs to test -std=c99 builds.
    6af08f4201 tests: Fix order of includes in barrier/id-fpool/mpsc-queue tests.
    4e475523c6 sflow: Always enable _BSD_SOURCE.
    b40af61940 compiler.h: Don't use asm and typeof with non-GNU compilers.
    e99e98655b Prepare for 3.2.1.


* Fri Aug 25 2023 Flavio Leitner <fbl@redhat.com> - 3.2.0-1
- redhat: Use official 3.2.0 tarball. [RH git: 14fbd4e97b]
    Signed-off-by: Flavio Leitner <fbl@redhat.com>


